'''
Manage sensitivity classifications.
'''
from .... pyaz_utils import _call_az
from . import recommendation


def list(name, resource_group, server, count=None, filter=None, skip_token=None):
    '''
    Get the sensitivity classifications of a given database.

    Required Parameters:
    - name -- Name of the Azure SQL Database.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`

    Optional Parameters:
    - count -- 
    - filter -- An OData filter expression that filters elements in the collection.
    - skip_token -- 
    '''
    return _call_az("az sql db classification list", locals())


def show(column, name, resource_group, schema, server, table):
    '''
    Get the sensitivity classification of a given column.

    Required Parameters:
    - column -- The name of the column.
    - name -- Name of the Azure SQL Database.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - schema -- The name of the schema.
    - server -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`
    - table -- The name of the table.
    '''
    return _call_az("az sql db classification show", locals())


def delete(column, name, resource_group, schema, server, table):
    '''
    Delete the sensitivity classification of a given column.

    Required Parameters:
    - column -- The name of the column.
    - name -- Name of the Azure SQL Database.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - schema -- The name of the schema.
    - server -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`
    - table -- The name of the table.
    '''
    return _call_az("az sql db classification delete", locals())


def update(column, name, resource_group, schema, server, table, information_type=None, label=None):
    '''
    Update a columns's sensitivity classification.

    Required Parameters:
    - column -- The name of the column.
    - name -- Name of the Azure SQL Database.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - schema -- The name of the schema.
    - server -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`
    - table -- The name of the table.

    Optional Parameters:
    - information_type -- The information type.
    - label -- The label name.
    '''
    return _call_az("az sql db classification update", locals())




'''
Manage function app functions.
'''
from ... pyaz_utils import _call_az
from . import keys


def show(function_name, name, resource_group):
    '''
    Get the details of a function.

    Required Parameters:
    - function_name -- Name of the Function
    - name -- Name of the function app
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az functionapp function show", locals())


def delete(function_name, name, resource_group):
    '''
    Delete a function.

    Required Parameters:
    - function_name -- Name of the Function
    - name -- Name of the function app
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az functionapp function delete", locals())




from ... pyaz_utils import _call_az
from . import node, vm_extension, vm_secret


def list(cluster_name, resource_group):
    '''
    List node types of a managed cluster.

    Required Parameters:
    - cluster_name -- Specify the name of the cluster, if not given it will be same as resource group name
    - resource_group -- Specify the resource group name. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az sf managed-node-type list", locals())


def delete(cluster_name, resource_group):
    '''
    Delete node type from a cluster.

    Required Parameters:
    - cluster_name -- Specify the name of the cluster, if not given it will be same as resource group name
    - resource_group -- Specify the resource group name. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az sf managed-node-type delete", locals())


def show(cluster_name, resource_group):
    '''
    Show the properties of a node type.

    Required Parameters:
    - cluster_name -- Specify the name of the cluster, if not given it will be same as resource group name
    - resource_group -- Specify the resource group name. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az sf managed-node-type show", locals())


def create(cluster_name, instance_count, resource_group, application_end_port=None, application_start_port=None, capacity=None, disk_size=None, disk_type=None, ephemeral_end_port=None, ephemeral_start_port=None, is_stateless=None, multiple_placement_groups=None, placement_property=None, primary=None, vm_image_offer=None, vm_image_publisher=None, vm_image_sku=None, vm_image_version=None, vm_size=None):
    '''
    Delete a managed cluster.

    Required Parameters:
    - cluster_name -- Specify the name of the cluster, if not given it will be same as resource group name
    - instance_count -- essage = "The number of nodes in the node type.
    - resource_group -- Specify the resource group name. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - application_end_port -- Application End port of a range of ports.
    - application_start_port -- Application start port of a range of ports.
    - capacity -- Capacity tags applied to the nodes in the node type as key/value pairs, the cluster resource manager uses these tags to understand how much resource a node has. Updating this will override the current values.for example: --capacity ClientConnections=65536 param2=value2
    - disk_size -- Disk size for each vm in the node type in GBs.
    - disk_type -- Managed data disk type. IOPS and throughput are given by the disk size, to see more information go to https://docs.microsoft.com/azure/virtual-machines/disks-types. Default StandardSSD_LRSStandard_LRS: Standard HDD locally redundant storage. Best for backup, non-critical, and infrequent access.StandardSSD_LRS: Standard SSD locally redundant storage. Best for web servers, lightly used enterprise applications and dev/test.Premium_LRS: Premium SSD locally redundant storage. Best for production and performance sensitive workloads.
    - ephemeral_end_port -- Ephemeral end port of a range of ports.
    - ephemeral_start_port -- Ephemeral start port of a range of ports.
    - is_stateless -- Indicates if the node type can only host Stateless workloads.
    - multiple_placement_groups -- Indicates if scale set associated with the node type can be composed of multiple placement groups.
    - placement_property -- Placement tags applied to nodes in the node type as key/value pairs, which can be used to indicate where certain services (workload) should run. Updating this will override the current values.for example: --placement-property NodeColor=Green SomeProperty=5
    - primary -- Specify if the node type is primary. On this node type will run system services. Only one node type should be marked as primary. Primary node type cannot be deleted or changed for existing clusters.
    - vm_image_offer -- The offer type of the Azure Virtual Machines Marketplace image.
    - vm_image_publisher -- The publisher of the Azure Virtual Machines Marketplace image.
    - vm_image_sku -- The SKU of the Azure Virtual Machines Marketplace image.
    - vm_image_version -- The version of the Azure Virtual Machines Marketplace image. 
    - vm_size -- The size of virtual machines in the pool. All virtual machines in a pool are the same size.
    '''
    return _call_az("az sf managed-node-type create", locals())


def update(cluster_name, resource_group, application_end_port=None, application_start_port=None, capacity=None, ephemeral_end_port=None, ephemeral_start_port=None, instance_count=None, placement_property=None):
    '''
    Update a managed cluster.

    Required Parameters:
    - cluster_name -- Specify the name of the cluster, if not given it will be same as resource group name
    - resource_group -- Specify the resource group name. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - application_end_port -- Application End port of a range of ports.
    - application_start_port -- Application start port of a range of ports.
    - capacity -- Capacity tags applied to the nodes in the node type as key/value pairs, the cluster resource manager uses these tags to understand how much resource a node has. Updating this will override the current values.for example: --capacity ClientConnections=65536 param2=value2
    - ephemeral_end_port -- Ephemeral end port of a range of ports.
    - ephemeral_start_port -- Ephemeral start port of a range of ports.
    - instance_count -- essage = "The number of nodes in the node type.
    - placement_property -- Placement tags applied to nodes in the node type as key/value pairs, which can be used to indicate where certain services (workload) should run. Updating this will override the current values.for example: --placement-property NodeColor=Green SomeProperty=5
    '''
    return _call_az("az sf managed-node-type update", locals())




from .... pyaz_utils import _call_az

def add(cluster_name, resource_group, admin_client_thumbprints=None, certificate_common_name=None, certificate_issuer_thumbprint=None, client_certificate_common_names=None, is_admin=None, readonly_client_thumbprints=None, thumbprint=None):
    '''
    Add a common name or certificate thumbprint to the cluster for client authentication.

    Required Parameters:
    - cluster_name -- Specify the name of the cluster, if not given it will be same as resource group name
    - resource_group -- Specify the resource group name. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - admin_client_thumbprints -- client certificate thumbprint that only has admin permission.
    - certificate_common_name -- client certificate common name.
    - certificate_issuer_thumbprint -- client certificate issuer thumbprint.
    - client_certificate_common_names -- JSON encoded parameters configuration. Use @{file} to load from a file. For example: [{"isAdmin":true, "certificateCommonName": "test.com", "certificateIssuerThumbprint": "22B4AE296B504E512DF880A77A2CAE20200FF922"}]
    - is_admin -- Client authentication type.
    - readonly_client_thumbprints -- Space-separated list of client certificate thumbprint that has read only permission.
    - thumbprint -- client certificate thumbprint.
    '''
    return _call_az("az sf cluster client-certificate add", locals())


def remove(cluster_name, resource_group, certificate_common_name=None, certificate_issuer_thumbprint=None, client_certificate_common_names=None, thumbprints=None):
    '''
    Remove client certificates or subject names used for authentication.

    Required Parameters:
    - cluster_name -- Specify the name of the cluster, if not given it will be same as resource group name
    - resource_group -- Specify the resource group name. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - certificate_common_name -- client certificate common name.
    - certificate_issuer_thumbprint -- client certificate issuer thumbprint.
    - client_certificate_common_names -- JSON encoded parameters configuration. Use @{file} to load from a file. For example: [{"certificateCommonName": "test.com","certificateIssuerThumbprint": "22B4AE296B504E512DF880A77A2CAE20200FF922"}]
    - thumbprints -- A single or Space-separated list of client certificate thumbprint(s) to be remove.
    '''
    return _call_az("az sf cluster client-certificate remove", locals())




from .... pyaz_utils import _call_az

def list(date_time_begin, date_time_end, max_ranking, metrics, profile_name, rankings, resource_group, actions=None, rule_types=None):
    '''
    

    Required Parameters:
    - date_time_begin -- The start datetime.
    - date_time_end -- The end datetime.
    - max_ranking -- The maximum number of rows to return based on the ranking.
    - metrics -- Metric types to be included.
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - rankings -- The dimemsions to be included for ranking.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - actions -- The WAF actions to be included.
    - rule_types -- The WAF rule types to be included.
    '''
    return _call_az("az afd waf-log-analytic ranking list", locals())




from .... pyaz_utils import _call_az

def create(location, logs, name, event_hub_auth_rule=None, event_hub_name=None, service_bus_rule=None, storage_account=None, workspace=None):
    '''
    Create diagnostic settings for a subscription

    Required Parameters:
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - logs -- JSON encoded list of logs settings. Use '@{file}' to load from a file.
    - name -- The name of the diagnostic setting.

    Optional Parameters:
    - event_hub_auth_rule -- The resource Id for the event hub authorization rule.
    - event_hub_name -- The name of the event hub. If none is specified, the default event hub will be selected.
    - service_bus_rule -- The service bus rule ID of the service bus namespace in which you would like to have Event Hubs created for streaming the Activity Log. The rule ID is of the format '{service bus resource ID}/authorizationrules/{key name}'.
    - storage_account -- The resource id of the storage account to which you would like to send the Activity Log.
    - workspace -- The resource id of the log analytics workspace.
    '''
    return _call_az("az monitor diagnostic-settings subscription create", locals())


def delete(name, subscription_id=None, yes=None):
    '''
    

    Required Parameters:
    - name -- The name of the diagnostic setting.

    Optional Parameters:
    - subscription_id -- ==SUPPRESS==
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az monitor diagnostic-settings subscription delete", locals())


def show(name, subscription_id=None):
    '''
    

    Required Parameters:
    - name -- The name of the diagnostic setting.

    Optional Parameters:
    - subscription_id -- ==SUPPRESS==
    '''
    return _call_az("az monitor diagnostic-settings subscription show", locals())


def list(subscription_id=None):
    '''
    

    Optional Parameters:
    - subscription_id -- ==SUPPRESS==
    '''
    return _call_az("az monitor diagnostic-settings subscription list", locals())


def update(name, add=None, event_hub_auth_rule=None, event_hub_name=None, force_string=None, logs=None, remove=None, service_bus_rule=None, set=None, storage_account=None, subscription_id=None, workspace=None):
    '''
    Update diagnostic settings for a subscription.

    Required Parameters:
    - name -- The name of the diagnostic setting.

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - event_hub_auth_rule -- The resource Id for the event hub authorization rule.
    - event_hub_name -- The name of the event hub. If none is specified, the default event hub will be selected.
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - logs -- JSON encoded list of logs settings. Use '@{file}' to load from a file.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - service_bus_rule -- The service bus rule ID of the service bus namespace in which you would like to have Event Hubs created for streaming the Activity Log. The rule ID is of the format '{service bus resource ID}/authorizationrules/{key name}'.
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - storage_account -- The resource id of the storage account to which you would like to send the Activity Log.
    - subscription_id -- ==SUPPRESS==
    - workspace -- The resource id of the log analytics workspace.
    '''
    return _call_az("az monitor diagnostic-settings subscription update", locals())




from ... pyaz_utils import _call_az

def list(name, resource_group):
    '''
    

    Required Parameters:
    - name -- Name of the Cosmos DB database account
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az cosmosdb network-rule list", locals())


def add(name, resource_group, subnet, ignore_missing_endpoint=None, vnet_name=None):
    '''
    

    Required Parameters:
    - name -- Name of the Cosmos DB database account
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - subnet -- Name or ID of the subnet

    Optional Parameters:
    - ignore_missing_endpoint -- Create firewall rule before the virtual network has vnet service endpoint enabled.
    - vnet_name -- The name of the VNET, which must be provided in conjunction with the name of the subnet
    '''
    return _call_az("az cosmosdb network-rule add", locals())


def remove(name, resource_group, subnet, vnet_name=None):
    '''
    

    Required Parameters:
    - name -- Name of the Cosmos DB database account
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - subnet -- Name or ID of the subnet

    Optional Parameters:
    - vnet_name -- The name of the VNET, which must be provided in conjunction with the name of the subnet
    '''
    return _call_az("az cosmosdb network-rule remove", locals())




'''
Manage helm chart repositories for Azure Container Registries.
'''
from .... pyaz_utils import _call_az

def add(name, password=None, repository=None, resource_group=None, suffix=None, username=None):
    '''
    Add a helm chart repository from an Azure Container Registry through the Helm CLI.

    Required Parameters:
    - name -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`

    Optional Parameters:
    - password -- The password used to log into a container registry
    - repository -- ==SUPPRESS==
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - suffix -- The tenant suffix in registry login server. You may specify '--suffix tenant' if your registry login server is in the format 'registry-tenant.azurecr.io'. Applicable if you're accessing the registry from a different subscription or you have permission to access images but not the permission to manage the registry resource.
    - username -- The username used to log into a container registry
    '''
    return _call_az("az acr helm repo add", locals())




from ... pyaz_utils import _call_az

def list():
    '''
    Get details of secure score control definitions.
    '''
    return _call_az("az security secure-score-control-definitions list", locals())




'''
Manage function app deployment via source control.
'''
from .... pyaz_utils import _call_az

def config_local_git(name, resource_group, slot=None):
    '''
    Get a URL for a git repository endpoint to clone and push to for function app deployment.

    Required Parameters:
    - name -- name of the function app
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - slot -- the name of the slot. Default to the productions slot if not specified
    '''
    return _call_az("az functionapp deployment source config-local-git", locals())


def config_zip(name, resource_group, src, build_remote=None, slot=None, timeout=None):
    '''
    Perform deployment using the kudu zip push deployment for a function app.

    Required Parameters:
    - name -- name of the function app
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - src -- a zip file path for deployment

    Optional Parameters:
    - build_remote -- enable remote build during deployment
    - slot -- the name of the slot. Default to the productions slot if not specified
    - timeout -- Configurable timeout in seconds for checking the status of deployment
    '''
    return _call_az("az functionapp deployment source config-zip", locals())


def config(name, repo_url, resource_group, branch=None, git_token=None, github_action=None, manual_integration=None, repository_type=None, slot=None):
    '''
    Manage deployment from git or Mercurial repositories.

    Required Parameters:
    - name -- name of the function app
    - repo_url -- repository url to pull the latest source from, e.g. https://github.com/foo/foo-web
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - branch -- the branch name of the repository
    - git_token -- Git access token required for auto sync
    - github_action -- If using github action, default to False
    - manual_integration -- disable automatic sync between source control and web
    - repository_type -- repository type
    - slot -- the name of the slot. Default to the productions slot if not specified
    '''
    return _call_az("az functionapp deployment source config", locals())


def sync(name, resource_group, slot=None):
    '''
    Synchronize from the repository. Only needed under manual integration mode.

    Required Parameters:
    - name -- name of the function app
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - slot -- the name of the slot. Default to the productions slot if not specified
    '''
    return _call_az("az functionapp deployment source sync", locals())


def show(name, resource_group, slot=None):
    '''
    Get the details of a source control deployment configuration.

    Required Parameters:
    - name -- name of the function app
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - slot -- the name of the slot. Default to the productions slot if not specified
    '''
    return _call_az("az functionapp deployment source show", locals())


def delete(name, resource_group, slot=None):
    '''
    Delete a source control deployment configuration.

    Required Parameters:
    - name -- name of the function app
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - slot -- the name of the slot. Default to the productions slot if not specified
    '''
    return _call_az("az functionapp deployment source delete", locals())


def update_token(git_token=None):
    '''
    

    Optional Parameters:
    - git_token -- Git access token required for auto sync
    '''
    return _call_az("az functionapp deployment source update-token", locals())




'''
Manage function app keys.
'''
from ... pyaz_utils import _call_az

def set(key_name, key_type, name, resource_group, key_value=None, slot=None):
    '''
    Create or update a function app key.

    Required Parameters:
    - key_name -- Name of the key to set.
    - key_type -- Type of key.
    - name -- Name of the function app
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - key_value -- Value of the new key. If not provided, a value will be generated.
    - slot -- The name of the slot. Defaults to the productions slot if not specified
    '''
    return _call_az("az functionapp keys set", locals())


def list(name, resource_group, slot=None):
    '''
    List all function app keys.

    Required Parameters:
    - name -- Name of the function app
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - slot -- The name of the slot. Defaults to the productions slot if not specified
    '''
    return _call_az("az functionapp keys list", locals())


def delete(key_name, key_type, name, resource_group, slot=None):
    '''
    Delete a function app key.

    Required Parameters:
    - key_name -- Name of the key to set.
    - key_type -- Type of key.
    - name -- Name of the function app
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - slot -- The name of the slot. Defaults to the productions slot if not specified
    '''
    return _call_az("az functionapp keys delete", locals())




from ..... pyaz_utils import _call_az

def create(gateway_name, resource_group, rule_name, rule_set_name, variable, ignore_case=None, negate=None, no_wait=None, pattern=None):
    '''
    Create a rewrite rule condition.

    Required Parameters:
    - gateway_name -- Name of the application gateway.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - rule_name -- Name of the rewrite rule.
    - rule_set_name -- Name of the rewrite rule set.
    - variable -- The variable whose value is being evaluated.

    Optional Parameters:
    - ignore_case -- Make comparison case-insensitive.
    - negate -- Check the negation of the condition.
    - no_wait -- Do not wait for the long-running operation to finish.
    - pattern -- The pattern, either fixed string or regular expression, that evaluates the truthfulness of the condition
    '''
    return _call_az("az network application-gateway rewrite-rule condition create", locals())


def show(gateway_name, resource_group, rule_name, rule_set_name, variable):
    '''
    Get the details of a rewrite rule condition.

    Required Parameters:
    - gateway_name -- Name of the application gateway.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - rule_name -- Name of the rewrite rule.
    - rule_set_name -- Name of the rewrite rule set.
    - variable -- The variable whose value is being evaluated.
    '''
    return _call_az("az network application-gateway rewrite-rule condition show", locals())


def list(gateway_name, resource_group, rule_name, rule_set_name):
    '''
    List rewrite rule conditions.

    Required Parameters:
    - gateway_name -- Name of the application gateway.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - rule_name -- Name of the rewrite rule.
    - rule_set_name -- Name of the rewrite rule set.
    '''
    return _call_az("az network application-gateway rewrite-rule condition list", locals())


def delete(gateway_name, resource_group, rule_name, rule_set_name, variable, no_wait=None):
    '''
    Delete a rewrite rule condition.

    Required Parameters:
    - gateway_name -- Name of the application gateway.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - rule_name -- Name of the rewrite rule.
    - rule_set_name -- Name of the rewrite rule set.
    - variable -- The variable whose value is being evaluated.

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az network application-gateway rewrite-rule condition delete", locals())


def update(gateway_name, resource_group, rule_name, rule_set_name, variable, add=None, force_string=None, ignore_case=None, negate=None, no_wait=None, pattern=None, remove=None, set=None):
    '''
    Update a rewrite rule condition.

    Required Parameters:
    - gateway_name -- Name of the application gateway.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - rule_name -- Name of the rewrite rule.
    - rule_set_name -- Name of the rewrite rule set.
    - variable -- The variable whose value is being evaluated.

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - ignore_case -- Make comparison case-insensitive.
    - negate -- Check the negation of the condition.
    - no_wait -- Do not wait for the long-running operation to finish.
    - pattern -- The pattern, either fixed string or regular expression, that evaluates the truthfulness of the condition
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    '''
    return _call_az("az network application-gateway rewrite-rule condition update", locals())


def list_server_variables():
    return _call_az("az network application-gateway rewrite-rule condition list-server-variables", locals())




from .... pyaz_utils import _call_az

def set(enabled, gateway_name, resource_group, disabled_rule_groups=None, disabled_rules=None, exclusion=None, file_upload_limit=None, firewall_mode=None, max_request_body_size=None, no_wait=None, request_body_check=None, rule_set_type=None, rule_set_version=None):
    '''
    Update the firewall configuration of a web application.

    Required Parameters:
    - enabled -- Specify whether the application firewall is enabled.
    - gateway_name -- Name of the application gateway.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - disabled_rule_groups -- None
    - disabled_rules -- None
    - exclusion -- None
    - file_upload_limit -- File upload size limit in MB.
    - firewall_mode -- Web application firewall mode.
    - max_request_body_size -- Max request body size in KB.
    - no_wait -- Do not wait for the long-running operation to finish.
    - request_body_check -- Allow WAF to check the request body.
    - rule_set_type -- None
    - rule_set_version -- None
    '''
    return _call_az("az network application-gateway waf-config set", locals())


def show(gateway_name, resource_group):
    '''
    Get the firewall configuration of a web application.

    Required Parameters:
    - gateway_name -- Name of the application gateway.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network application-gateway waf-config show", locals())


def list_rule_sets(group=None, type=None, version=None):
    '''
    Get information on available WAF rule sets, rule groups, and rule IDs.

    Optional Parameters:
    - group -- None
    - type -- None
    - version -- None
    '''
    return _call_az("az network application-gateway waf-config list-rule-sets", locals())




from .... pyaz_utils import _call_az

def show(name, resource_group, system_topic_name, include_full_endpoint_url=None, include_static_delivery_attribute_secret=None):
    '''
    Get the details of an event subscription of a system topic.

    Required Parameters:
    - name -- Name of the event subscription.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - system_topic_name -- Name of the system topic.

    Optional Parameters:
    - include_full_endpoint_url -- Specify to indicate whether the full endpoint URL should be returned. True if flag present.
    - include_static_delivery_attribute_secret -- Indicate whether any static delivery attribute secrets should be returned. True if flag present.
    '''
    return _call_az("az eventgrid system-topic event-subscription show", locals())


def delete(name, resource_group, system_topic_name, yes=None):
    '''
    Delete an event subscription of a system topic

    Required Parameters:
    - name -- Name of the event subscription.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - system_topic_name -- Name of the system topic.

    Optional Parameters:
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az eventgrid system-topic event-subscription delete", locals())


def list(resource_group, system_topic_name, odata_query=None):
    '''
    List event subscriptions of a specific system topic.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - system_topic_name -- Name of the system topic.

    Optional Parameters:
    - odata_query -- The OData query used for filtering the list results. Filtering is currently allowed on the Name property only. The supported operations include: CONTAINS, eq (for equal), ne (for not equal), AND, OR and NOT.
    '''
    return _call_az("az eventgrid system-topic event-subscription list", locals())


def create(name, resource_group, system_topic_name, advanced_filter=None, azure_active_directory_application_id_or_uri=None, azure_active_directory_tenant_id=None, deadletter_endpoint=None, delivery_attribute_mapping=None, enable_advanced_filtering_on_arrays=None, endpoint=None, endpoint_type=None, event_delivery_schema=None, event_ttl=None, expiration_date=None, included_event_types=None, labels=None, max_delivery_attempts=None, max_events_per_batch=None, preferred_batch_size_in_kilobytes=None, storage_queue_msg_ttl=None, subject_begins_with=None, subject_case_sensitive=None, subject_ends_with=None):
    '''
    Create a new event subscription for a system topic

    Required Parameters:
    - name -- Name of the event subscription.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - system_topic_name -- Name of the system topic.

    Optional Parameters:
    - advanced_filter -- None
    - azure_active_directory_application_id_or_uri -- The Azure Active Directory Application Id or Uri to get the access token that will be included as the bearer token in delivery requests. Applicable only for webhook as a destination
    - azure_active_directory_tenant_id -- The Azure Active Directory Tenant Id to get the access token that will be included as the bearer token in delivery requests. Applicable only for webhook as a destination
    - deadletter_endpoint -- The Azure resource ID of an Azure Storage blob container destination where EventGrid should deadletter undeliverable events for this event subscription.
    - delivery_attribute_mapping -- Add delivery attribute mapping to send additional information via HTTP headers when delivering events. This attribute is valid for all destination types except StorageQueue. Multiple attributes can be specified by using more than one `--delivery-attribute-mapping` argument
    - enable_advanced_filtering_on_arrays -- Allows advanced filters to be evaluated against an array of values instead of expecting a singular value.
    - endpoint -- Endpoint where EventGrid should deliver events matching this event subscription. For webhook endpoint type, this should be the corresponding webhook URL. For other endpoint types, this should be the Azure resource identifier of the endpoint. It is expected that the destination endpoint to be already created and available for use before executing any Event Grid command.
    - endpoint_type -- None
    - event_delivery_schema -- The schema in which events should be delivered for this event subscription. By default, events will be delivered in the same schema in which they are published (based on the corresponding topic's input schema).
    - event_ttl -- Event time to live (in minutes). Must be a number between 1 and 1440.
    - expiration_date -- Date or datetime (in UTC, e.g. '2018-11-30T11:59:59+00:00' or '2018-11-30') after which the event subscription would expire. By default, there is no expiration for the event subscription.
    - included_event_types -- A space-separated list of event types (e.g., Microsoft.Storage.BlobCreated and Microsoft.Storage.BlobDeleted). In order to subscribe to all default event types, do not specify any value for this argument. For event grid topics, event types are customer defined. For Azure events, e.g., Storage Accounts, IoT Hub, etc., you can query their event types using this CLI command 'az eventgrid topic-type list-event-types'.
    - labels -- A space-separated list of labels to associate with this event subscription.
    - max_delivery_attempts -- Maximum number of delivery attempts. Must be a number between 1 and 30.
    - max_events_per_batch -- Maximum number of events in a batch. Must be a number between 1 and 5000.
    - preferred_batch_size_in_kilobytes -- Preferred batch size in kilobytes. Must be a number between 1 and 1024.
    - storage_queue_msg_ttl -- Storage queue message time to live in seconds.
    - subject_begins_with -- An optional string to filter events for an event subscription based on a prefix. Wildcard characters are not supported.
    - subject_case_sensitive -- Specify to indicate whether the subject fields should be compared in a case sensitive manner. True if flag present.
    - subject_ends_with -- An optional string to filter events for an event subscription based on a suffix. Wildcard characters are not supported.
    '''
    return _call_az("az eventgrid system-topic event-subscription create", locals())


def update(name, resource_group, system_topic_name, advanced_filter=None, deadletter_endpoint=None, delivery_attribute_mapping=None, enable_advanced_filtering_on_arrays=None, endpoint=None, endpoint_type=None, included_event_types=None, labels=None, storage_queue_msg_ttl=None, subject_begins_with=None, subject_ends_with=None):
    '''
    Update an event subscription of a system topic.

    Required Parameters:
    - name -- Name of the event subscription.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - system_topic_name -- Name of the system topic.

    Optional Parameters:
    - advanced_filter -- None
    - deadletter_endpoint -- The Azure resource ID of an Azure Storage blob container destination where EventGrid should deadletter undeliverable events for this event subscription.
    - delivery_attribute_mapping -- Add delivery attribute mapping to send additional information via HTTP headers when delivering events. This attribute is valid for all destination types except StorageQueue. Multiple attributes can be specified by using more than one `--delivery-attribute-mapping` argument
    - enable_advanced_filtering_on_arrays -- Allows advanced filters to be evaluated against an array of values instead of expecting a singular value.
    - endpoint -- Endpoint where EventGrid should deliver events matching this event subscription. For webhook endpoint type, this should be the corresponding webhook URL. For other endpoint types, this should be the Azure resource identifier of the endpoint. It is expected that the destination endpoint to be already created and available for use before executing any Event Grid command.
    - endpoint_type -- None
    - included_event_types -- A space-separated list of event types (e.g., Microsoft.Storage.BlobCreated and Microsoft.Storage.BlobDeleted). In order to subscribe to all default event types, do not specify any value for this argument. For event grid topics, event types are customer defined. For Azure events, e.g., Storage Accounts, IoT Hub, etc., you can query their event types using this CLI command 'az eventgrid topic-type list-event-types'.
    - labels -- A space-separated list of labels to associate with this event subscription.
    - storage_queue_msg_ttl -- Storage queue message time to live in seconds.
    - subject_begins_with -- An optional string to filter events for an event subscription based on a prefix. Wildcard characters are not supported.
    - subject_ends_with -- An optional string to filter events for an event subscription based on a suffix. Wildcard characters are not supported.
    '''
    return _call_az("az eventgrid system-topic event-subscription update", locals())




'''
Manage media reserved units for an Azure Media Services account. This doesn't work with accounts created with 2020-05-01 version of the Media Services API or later. Accounts created this way no longer need to set media reserved units as the system will automaticaly scale up and down based on load.
'''
from .... pyaz_utils import _call_az

def show(name, resource_group):
    '''
    Show the details of media reserved units for an Azure Media Services account. This doesn't work with accounts created with 2020-05-01 version of the Media Services API or later. Accounts created this way no longer need to set media reserved units as the system will automaticaly scale up and down based on load.

    Required Parameters:
    - name -- The name of the Azure Media Services account.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az ams account mru show", locals())


def set(name, resource_group, count=None, type=None):
    '''
    Set the type and number of media reserved units for an Azure Media Services account. This doesn't work with accounts created with 2020-05-01 version of the Media Services API or later. Accounts created this way no longer need to set media reserved units as the system will automaticaly scale up and down based on load.

    Required Parameters:
    - name -- The name of the Azure Media Services account.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - count -- The number of the encoding reserved units that you want to be provisioned for this account for concurrent tasks (one unit equals one task).
    - type -- Speed of reserved processing units. The cost of media encoding depends on the pricing tier you choose. See https://azure.microsoft.com/pricing/details/media-services/ for further details. Allowed values: S1, S2, S3.
    '''
    return _call_az("az ams account mru set", locals())




'''
Manage private Tasks agent pools with Azure Container Registries.
'''
from ... pyaz_utils import _call_az

def create(name, registry, count=None, no_wait=None, os=None, resource_group=None, subnet_id=None, tier=None):
    '''
    Create an agent pool for an Azure Container Registry.

    Required Parameters:
    - name -- The name of the agent pool.
    - registry -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`

    Optional Parameters:
    - count -- The count of the agent pool.
    - no_wait -- Do not wait for the Agent Pool to complete action and return immediately after queuing the request.
    - os -- The os of the agent pool.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - subnet_id -- The Virtual Network Subnet Resource Id of the agent machine.
    - tier -- Sets the VM your agent pool will run on. Valid values are: S1(2 vCPUs, 3 GiB RAM), S2(4 vCPUs, 8 GiB RAM), S3(8 vCPUs, 16 GiB RAM) or I6(64 vCPUs, 216 GiB RAM, Isolated)
    '''
    return _call_az("az acr agentpool create", locals())


def update(name, registry, count=None, no_wait=None, resource_group=None):
    '''
    Update an agent pool for an Azure Container Registry.

    Required Parameters:
    - name -- The name of the agent pool.
    - registry -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`

    Optional Parameters:
    - count -- The count of the agent pool.
    - no_wait -- Do not wait for the Agent Pool to complete action and return immediately after queuing the request.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az acr agentpool update", locals())


def delete(name, registry, no_wait=None, resource_group=None, yes=None):
    '''
    Delete an agent pool.

    Required Parameters:
    - name -- The name of the agent pool.
    - registry -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`

    Optional Parameters:
    - no_wait -- Do not wait for the Agent Pool to complete action and return immediately after queuing the request.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az acr agentpool delete", locals())


def list(registry, resource_group=None):
    '''
    List the agent pools for an Azure Container Registry.

    Required Parameters:
    - registry -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az acr agentpool list", locals())


def show(name, registry, queue_count=None, resource_group=None):
    '''
    Get the properties of a specified agent pool for an Azure Container Registry.

    Required Parameters:
    - name -- The name of the agent pool.
    - registry -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`

    Optional Parameters:
    - queue_count -- Get only the queue count
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az acr agentpool show", locals())




'''
Manage feature flags stored in an App Configuration.
'''
from ... pyaz_utils import _call_az
from . import filter


def set(auth_mode=None, connection_string=None, description=None, endpoint=None, feature=None, key=None, label=None, name=None, yes=None):
    '''
    Set a feature flag.

    Optional Parameters:
    - auth_mode -- This parameter can be used for indicating how a data operation is to be authorized. If the auth mode is "key", provide connection string or store name and your account access keys will be retrieved for authorization. If the auth mode is "login", provide the store endpoint or store name and your "az login" credentials will be used for authorization. You can configure the default auth mode using `az configure --defaults appconfig_auth_mode=<auth_mode>`. For more information, see https://docs.microsoft.com/azure/azure-app-configuration/concept-enable-rbac
    - connection_string -- Combination of access key and endpoint of App Configuration. Can be found using 'az appconfig credential list'. Users can preset it using `az configure --defaults appconfig_connection_string=<connection_string>` or environment variable with the name AZURE_APPCONFIG_CONNECTION_STRING.
    - description -- Description of the feature flag to be set.
    - endpoint -- If auth mode is "login", provide endpoint URL of the App Configuration. The endpoint can be retrieved using "az appconfig show" command. You can configure the default endpoint using `az configure --defaults appconfig_endpoint=<endpoint>`
    - feature -- Name of the feature flag to be set. Feature name cannot contain the '%' character.
    - key -- Key of the feature flag. Key must start with the ".appconfig.featureflag/" prefix. Key cannot contain the "%" character. Default key is the reserved prefix ".appconfig.featureflag/" + feature name.
    - label -- If no label specified, set the feature flag with null label by default
    - name -- Name of the App Configuration. You can configure the default name using `az configure --defaults app_configuration_store=<name>`
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az appconfig feature set", locals())


def delete(auth_mode=None, connection_string=None, endpoint=None, feature=None, key=None, label=None, name=None, yes=None):
    '''
    Delete feature flag.

    Optional Parameters:
    - auth_mode -- This parameter can be used for indicating how a data operation is to be authorized. If the auth mode is "key", provide connection string or store name and your account access keys will be retrieved for authorization. If the auth mode is "login", provide the store endpoint or store name and your "az login" credentials will be used for authorization. You can configure the default auth mode using `az configure --defaults appconfig_auth_mode=<auth_mode>`. For more information, see https://docs.microsoft.com/azure/azure-app-configuration/concept-enable-rbac
    - connection_string -- Combination of access key and endpoint of App Configuration. Can be found using 'az appconfig credential list'. Users can preset it using `az configure --defaults appconfig_connection_string=<connection_string>` or environment variable with the name AZURE_APPCONFIG_CONNECTION_STRING.
    - endpoint -- If auth mode is "login", provide endpoint URL of the App Configuration. The endpoint can be retrieved using "az appconfig show" command. You can configure the default endpoint using `az configure --defaults appconfig_endpoint=<endpoint>`
    - feature -- Name of the feature to be deleted. If the feature flag key is different from the default key, provide the `--key` argument instead. Support star sign as filters, for instance * means all features and abc* means features with abc as prefix. Comma separated features are not supported. Please provide escaped string if your feature name contains comma.
    - key -- Key of the feature flag. Key must start with the ".appconfig.featureflag/" prefix. Key cannot contain the "%" character. If both key and feature arguments are provided, only key will be used. Support star sign as filters, for instance ".appconfig.featureflag/*" means all features and ".appconfig.featureflag/abc*" means features with abc as prefix. Comma separated features are not supported. Please provide escaped string if your feature name contains comma.
    - label -- If no label specified, delete the feature flag with null label by default. Support star sign as filters, for instance * means all labels and abc* means labels with abc as prefix.
    - name -- Name of the App Configuration. You can configure the default name using `az configure --defaults app_configuration_store=<name>`
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az appconfig feature delete", locals())


def show(auth_mode=None, connection_string=None, endpoint=None, feature=None, fields=None, key=None, label=None, name=None):
    '''
    Show all attributes of a feature flag.

    Optional Parameters:
    - auth_mode -- This parameter can be used for indicating how a data operation is to be authorized. If the auth mode is "key", provide connection string or store name and your account access keys will be retrieved for authorization. If the auth mode is "login", provide the store endpoint or store name and your "az login" credentials will be used for authorization. You can configure the default auth mode using `az configure --defaults appconfig_auth_mode=<auth_mode>`. For more information, see https://docs.microsoft.com/azure/azure-app-configuration/concept-enable-rbac
    - connection_string -- Combination of access key and endpoint of App Configuration. Can be found using 'az appconfig credential list'. Users can preset it using `az configure --defaults appconfig_connection_string=<connection_string>` or environment variable with the name AZURE_APPCONFIG_CONNECTION_STRING.
    - endpoint -- If auth mode is "login", provide endpoint URL of the App Configuration. The endpoint can be retrieved using "az appconfig show" command. You can configure the default endpoint using `az configure --defaults appconfig_endpoint=<endpoint>`
    - feature -- Name of the feature flag to be retrieved. If the feature flag key is different from the default key, provide the `--key` argument instead.
    - fields -- Customize output fields for Feature Flags.
    - key -- Key of the feature flag. Key must start with the ".appconfig.featureflag/" prefix. Key cannot contain the "%" character. If both key and feature arguments are provided, only key will be used. Default key is the reserved prefix ".appconfig.featureflag/" + feature name.
    - label -- If no label specified, show entry with null label. Filtering is not supported.
    - name -- Name of the App Configuration. You can configure the default name using `az configure --defaults app_configuration_store=<name>`
    '''
    return _call_az("az appconfig feature show", locals())


def list(all=None, auth_mode=None, connection_string=None, endpoint=None, feature=None, fields=None, key=None, label=None, name=None, top=None):
    '''
    List feature flags.

    Optional Parameters:
    - all -- List all feature flags.
    - auth_mode -- This parameter can be used for indicating how a data operation is to be authorized. If the auth mode is "key", provide connection string or store name and your account access keys will be retrieved for authorization. If the auth mode is "login", provide the store endpoint or store name and your "az login" credentials will be used for authorization. You can configure the default auth mode using `az configure --defaults appconfig_auth_mode=<auth_mode>`. For more information, see https://docs.microsoft.com/azure/azure-app-configuration/concept-enable-rbac
    - connection_string -- Combination of access key and endpoint of App Configuration. Can be found using 'az appconfig credential list'. Users can preset it using `az configure --defaults appconfig_connection_string=<connection_string>` or environment variable with the name AZURE_APPCONFIG_CONNECTION_STRING.
    - endpoint -- If auth mode is "login", provide endpoint URL of the App Configuration. The endpoint can be retrieved using "az appconfig show" command. You can configure the default endpoint using `az configure --defaults appconfig_endpoint=<endpoint>`
    - feature -- Name of the feature to be listed. If the feature flag key is different from the default key, provide the `--key` argument instead. Support star sign as filters, for instance * means all features and abc* means features with abc as prefix. Comma separated features are not supported. Please provide escaped string if your feature name contains comma.
    - fields -- Customize output fields for Feature Flags.
    - key -- Key of the feature flag. Key must start with the ".appconfig.featureflag/" prefix. Key cannot contain the "%" character. If both key and feature arguments are provided, only key will be used. Support star sign as filters, for instance ".appconfig.featureflag/*" means all features and ".appconfig.featureflag/abc*" means features with abc as prefix. Comma separated features are not supported. Please provide escaped string if your feature name contains comma.
    - label -- If no label specified, list all labels. Support star sign as filters, for instance * means all labels and abc* means labels with abc as prefix. Use '\0' for null label.
    - name -- Name of the App Configuration. You can configure the default name using `az configure --defaults app_configuration_store=<name>`
    - top -- Maximum number of items to return. Must be a positive integer. Default to 100.
    '''
    return _call_az("az appconfig feature list", locals())


def lock(auth_mode=None, connection_string=None, endpoint=None, feature=None, key=None, label=None, name=None, yes=None):
    '''
    Lock a feature flag to prohibit write operations.

    Optional Parameters:
    - auth_mode -- This parameter can be used for indicating how a data operation is to be authorized. If the auth mode is "key", provide connection string or store name and your account access keys will be retrieved for authorization. If the auth mode is "login", provide the store endpoint or store name and your "az login" credentials will be used for authorization. You can configure the default auth mode using `az configure --defaults appconfig_auth_mode=<auth_mode>`. For more information, see https://docs.microsoft.com/azure/azure-app-configuration/concept-enable-rbac
    - connection_string -- Combination of access key and endpoint of App Configuration. Can be found using 'az appconfig credential list'. Users can preset it using `az configure --defaults appconfig_connection_string=<connection_string>` or environment variable with the name AZURE_APPCONFIG_CONNECTION_STRING.
    - endpoint -- If auth mode is "login", provide endpoint URL of the App Configuration. The endpoint can be retrieved using "az appconfig show" command. You can configure the default endpoint using `az configure --defaults appconfig_endpoint=<endpoint>`
    - feature -- Name of the feature to be locked. If the feature flag key is different from the default key, provide the `--key` argument instead.
    - key -- Key of the feature flag. Key must start with the ".appconfig.featureflag/" prefix. Key cannot contain the "%" character. If both key and feature arguments are provided, only key will be used. Default key is the reserved prefix ".appconfig.featureflag/" + feature name.
    - label -- If no label specified, lock the feature flag with null label by default.
    - name -- Name of the App Configuration. You can configure the default name using `az configure --defaults app_configuration_store=<name>`
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az appconfig feature lock", locals())


def unlock(auth_mode=None, connection_string=None, endpoint=None, feature=None, key=None, label=None, name=None, yes=None):
    '''
    Unlock a feature to gain write operations.

    Optional Parameters:
    - auth_mode -- This parameter can be used for indicating how a data operation is to be authorized. If the auth mode is "key", provide connection string or store name and your account access keys will be retrieved for authorization. If the auth mode is "login", provide the store endpoint or store name and your "az login" credentials will be used for authorization. You can configure the default auth mode using `az configure --defaults appconfig_auth_mode=<auth_mode>`. For more information, see https://docs.microsoft.com/azure/azure-app-configuration/concept-enable-rbac
    - connection_string -- Combination of access key and endpoint of App Configuration. Can be found using 'az appconfig credential list'. Users can preset it using `az configure --defaults appconfig_connection_string=<connection_string>` or environment variable with the name AZURE_APPCONFIG_CONNECTION_STRING.
    - endpoint -- If auth mode is "login", provide endpoint URL of the App Configuration. The endpoint can be retrieved using "az appconfig show" command. You can configure the default endpoint using `az configure --defaults appconfig_endpoint=<endpoint>`
    - feature -- Name of the feature to be unlocked. If the feature flag key is different from the default key, provide the `--key` argument instead.
    - key -- Key of the feature flag. Key must start with the ".appconfig.featureflag/" prefix. Key cannot contain the "%" character. If both key and feature arguments are provided, only key will be used. Default key is the reserved prefix ".appconfig.featureflag/" + feature name.
    - label -- If no label specified, unlock the feature flag with null label by default.
    - name -- Name of the App Configuration. You can configure the default name using `az configure --defaults app_configuration_store=<name>`
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az appconfig feature unlock", locals())


def enable(auth_mode=None, connection_string=None, endpoint=None, feature=None, key=None, label=None, name=None, yes=None):
    '''
    Enable a feature flag to turn it ON for use.

    Optional Parameters:
    - auth_mode -- This parameter can be used for indicating how a data operation is to be authorized. If the auth mode is "key", provide connection string or store name and your account access keys will be retrieved for authorization. If the auth mode is "login", provide the store endpoint or store name and your "az login" credentials will be used for authorization. You can configure the default auth mode using `az configure --defaults appconfig_auth_mode=<auth_mode>`. For more information, see https://docs.microsoft.com/azure/azure-app-configuration/concept-enable-rbac
    - connection_string -- Combination of access key and endpoint of App Configuration. Can be found using 'az appconfig credential list'. Users can preset it using `az configure --defaults appconfig_connection_string=<connection_string>` or environment variable with the name AZURE_APPCONFIG_CONNECTION_STRING.
    - endpoint -- If auth mode is "login", provide endpoint URL of the App Configuration. The endpoint can be retrieved using "az appconfig show" command. You can configure the default endpoint using `az configure --defaults appconfig_endpoint=<endpoint>`
    - feature -- Name of the feature to be enabled. If the feature flag key is different from the default key, provide the `--key` argument instead.
    - key -- Key of the feature flag. Key must start with the ".appconfig.featureflag/" prefix. Key cannot contain the "%" character. If both key and feature arguments are provided, only key will be used. Default key is the reserved prefix ".appconfig.featureflag/" + feature name.
    - label -- If no label specified, enable the feature flag with null label by default.
    - name -- Name of the App Configuration. You can configure the default name using `az configure --defaults app_configuration_store=<name>`
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az appconfig feature enable", locals())


def disable(auth_mode=None, connection_string=None, endpoint=None, feature=None, key=None, label=None, name=None, yes=None):
    '''
    Disable a feature flag to turn it OFF for use.

    Optional Parameters:
    - auth_mode -- This parameter can be used for indicating how a data operation is to be authorized. If the auth mode is "key", provide connection string or store name and your account access keys will be retrieved for authorization. If the auth mode is "login", provide the store endpoint or store name and your "az login" credentials will be used for authorization. You can configure the default auth mode using `az configure --defaults appconfig_auth_mode=<auth_mode>`. For more information, see https://docs.microsoft.com/azure/azure-app-configuration/concept-enable-rbac
    - connection_string -- Combination of access key and endpoint of App Configuration. Can be found using 'az appconfig credential list'. Users can preset it using `az configure --defaults appconfig_connection_string=<connection_string>` or environment variable with the name AZURE_APPCONFIG_CONNECTION_STRING.
    - endpoint -- If auth mode is "login", provide endpoint URL of the App Configuration. The endpoint can be retrieved using "az appconfig show" command. You can configure the default endpoint using `az configure --defaults appconfig_endpoint=<endpoint>`
    - feature -- Name of the feature to be disabled. If the feature flag key is different from the default key, provide the `--key` argument instead.
    - key -- Key of the feature flag. Key must start with the ".appconfig.featureflag/" prefix. Key cannot contain the "%" character. If both key and feature arguments are provided, only key will be used. Default key is the reserved prefix ".appconfig.featureflag/" + feature name.
    - label -- If no label specified, disable the feature flag with null label by default.
    - name -- Name of the App Configuration. You can configure the default name using `az configure --defaults app_configuration_store=<name>`
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az appconfig feature disable", locals())




from .... pyaz_utils import _call_az

def show_sql_access(resource_group, workspace_name):
    '''
    Show workspace's sql-access state to managed-identity.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The workspace name.
    '''
    return _call_az("az synapse workspace managed-identity show-sql-access", locals())


def grant_sql_access(resource_group, workspace_name, no_wait=None):
    '''
    Grant workspace's sql-access to managed-identity.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The workspace name.

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az synapse workspace managed-identity grant-sql-access", locals())


def revoke_sql_access(resource_group, workspace_name, no_wait=None):
    '''
    Revoke workspace's sql-access to managed-identity.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The workspace name.

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az synapse workspace managed-identity revoke-sql-access", locals())


def wait(resource_group, workspace_name, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of sql-access state to managed-identity is met.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The workspace name.

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - interval -- polling interval in seconds
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az synapse workspace managed-identity wait", locals())




'''
Manage Azure IoT Hub Device Provisioning Service certificates.
'''
from .... pyaz_utils import _call_az

def list(dps_name, resource_group):
    '''
    List all certificates contained within an Azure IoT Hub device provisioning service

    Required Parameters:
    - dps_name -- IoT Provisioning Service name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az iot dps certificate list", locals())


def show(certificate_name, dps_name, resource_group):
    '''
    Show information about a particular Azure IoT Hub Device Provisioning Service certificate.

    Required Parameters:
    - certificate_name -- A friendly name for the certificate.
    - dps_name -- IoT Provisioning Service name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az iot dps certificate show", locals())


def create(certificate_name, dps_name, path, resource_group, verified=None):
    '''
    Create/upload an Azure IoT Hub Device Provisioning Service certificate.

    Required Parameters:
    - certificate_name -- A friendly name for the certificate.
    - dps_name -- IoT Provisioning Service name
    - path -- The path to the file containing the certificate.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - verified -- A boolean indicating whether or not the certificate is verified.
    '''
    return _call_az("az iot dps certificate create", locals())


def delete(certificate_name, dps_name, etag, resource_group):
    '''
    Delete an Azure IoT Hub Device Provisioning Service certificate.

    Required Parameters:
    - certificate_name -- A friendly name for the certificate.
    - dps_name -- IoT Provisioning Service name
    - etag -- Entity Tag (etag) of the object.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az iot dps certificate delete", locals())


def generate_verification_code(certificate_name, dps_name, etag, resource_group):
    '''
    Generate a verification code for an Azure IoT Hub Device Provisioning Service certificate.

    Required Parameters:
    - certificate_name -- A friendly name for the certificate.
    - dps_name -- IoT Provisioning Service name
    - etag -- Entity Tag (etag) of the object.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az iot dps certificate generate-verification-code", locals())


def verify(certificate_name, dps_name, etag, path, resource_group):
    '''
    Verify an Azure IoT Hub Device Provisioning Service certificate.

    Required Parameters:
    - certificate_name -- A friendly name for the certificate.
    - dps_name -- IoT Provisioning Service name
    - etag -- Entity Tag (etag) of the object.
    - path -- The path to the file containing the certificate.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az iot dps certificate verify", locals())


def update(certificate_name, dps_name, etag, path, resource_group, verified=None):
    '''
    Update an Azure IoT Hub Device Provisioning Service certificate.

    Required Parameters:
    - certificate_name -- A friendly name for the certificate.
    - dps_name -- IoT Provisioning Service name
    - etag -- Entity Tag (etag) of the object.
    - path -- The path to the file containing the certificate.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - verified -- A boolean indicating whether or not the certificate is verified.
    '''
    return _call_az("az iot dps certificate update", locals())




from ..... pyaz_utils import _call_az

def create(gateway_name, name, peering, resource_group, associated=None, authorization_key=None, circuit_name=None, internet_security=None, labels=None, propagated=None, routing_weight=None):
    '''
    Create an ExpressRoute gateway connection.

    Required Parameters:
    - gateway_name -- ExpressRoute gateway name.
    - name -- ExpressRoute connection name.
    - peering -- Name or ID of an ExpressRoute peering.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - associated -- The resource id of route table associated with this routing configuration.
    - authorization_key -- Authorization key to establish the connection.
    - circuit_name -- ExpressRoute circuit name.
    - internet_security -- Enable internet security. A virtual hub can have the ability to propagate a learned default route to this ExpressRoute connection. This ref https://review.docs.microsoft.com/en-us/azure/virtual-wan/effective-routes-virtual-hub?branch=pr-en-us-91866#aboutdefaultroute might be helpful.
    - labels -- Space-separated list of labels for propagated route tables.
    - propagated -- Space-separated list of resource id of propagated route tables.
    - routing_weight -- Routing weight associated with the connection.
    '''
    return _call_az("az network express-route gateway connection create", locals())


def delete(gateway_name, name, resource_group):
    '''
    Delete an ExpressRoute gateway connection.

    Required Parameters:
    - gateway_name -- ExpressRoute gateway name.
    - name -- ExpressRoute connection name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network express-route gateway connection delete", locals())


def list(gateway_name, resource_group):
    '''
    List ExpressRoute gateway connections.

    Required Parameters:
    - gateway_name -- ExpressRoute gateway name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network express-route gateway connection list", locals())


def show(gateway_name, name, resource_group):
    '''
    Get the details of an ExpressRoute gateway connection.

    Required Parameters:
    - gateway_name -- ExpressRoute gateway name.
    - name -- ExpressRoute connection name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network express-route gateway connection show", locals())


def update(gateway_name, name, resource_group, add=None, associated=None, authorization_key=None, circuit_name=None, force_string=None, internet_security=None, labels=None, peering=None, propagated=None, remove=None, routing_weight=None, set=None):
    '''
    Update an ExpressRoute gateway connection.

    Required Parameters:
    - gateway_name -- ExpressRoute gateway name.
    - name -- ExpressRoute connection name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - associated -- The resource id of route table associated with this routing configuration.
    - authorization_key -- Authorization key to establish the connection.
    - circuit_name -- ExpressRoute circuit name.
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - internet_security -- Enable internet security. A virtual hub can have the ability to propagate a learned default route to this ExpressRoute connection. This ref https://review.docs.microsoft.com/en-us/azure/virtual-wan/effective-routes-virtual-hub?branch=pr-en-us-91866#aboutdefaultroute might be helpful.
    - labels -- Space-separated list of labels for propagated route tables.
    - peering -- Name or ID of an ExpressRoute peering.
    - propagated -- Space-separated list of resource id of propagated route tables.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - routing_weight -- Routing weight associated with the connection.
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    '''
    return _call_az("az network express-route gateway connection update", locals())




'''
Manage service principal and role based access for an Azure Media Services account.
'''
from .... pyaz_utils import _call_az

def create(account_name, resource_group, name=None, new_sp_name=None, password=None, role=None, xml=None, years=None):
    '''
    Create or update a service principal and configure its access to an Azure Media Services account.

    Required Parameters:
    - account_name -- The name of the Azure Media Services account.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - name -- The app name or app URI to associate the RBAC with. If not present, a default name like '{amsaccountname}-access-sp' will be generated.
    - new_sp_name -- The new app name or app URI to update the RBAC with.
    - password -- The password used to log in. Also known as 'Client Secret'. If not present, a random secret will be generated.
    - role -- The role of the service principal.
    - xml -- Enables xml output format.
    - years -- Number of years for which the secret will be valid. Default: 1 year.
    '''
    return _call_az("az ams account sp create", locals())


def reset_credentials(account_name, resource_group, name=None, password=None, role=None, xml=None, years=None):
    '''
    Generate a new client secret for a service principal configured for an Azure Media Services account.

    Required Parameters:
    - account_name -- The name of the Azure Media Services account.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - name -- The app name or app URI to associate the RBAC with. If not present, a default name like '{amsaccountname}-access-sp' will be generated.
    - password -- The password used to log in. Also known as 'Client Secret'. If not present, a random secret will be generated.
    - role -- The role of the service principal.
    - xml -- Enables xml output format.
    - years -- Number of years for which the secret will be valid. Default: 1 year.
    '''
    return _call_az("az ams account sp reset-credentials", locals())




'''
Manage workspace's keys.
'''
from .... pyaz_utils import _call_az

def list(resource_group, workspace_name):
    '''
    List keys under specified workspace.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The workspace name.
    '''
    return _call_az("az synapse workspace key list", locals())


def show(name, resource_group, workspace_name):
    '''
    Show a workspace's key by name.

    Required Parameters:
    - name -- The workspace customer-managed key display name. All existing keys can be found using /"az synapse workspace key list/" cmdlet.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The workspace name.
    '''
    return _call_az("az synapse workspace key show", locals())


def create(key_identifier, name, resource_group, workspace_name, no_wait=None):
    '''
    Create a workspace's key.

    Required Parameters:
    - key_identifier -- The Key Vault Url of the workspace encryption key. should be in the format of: https://{keyvaultname}.vault.azure.net/keys/{keyname}.
    - name -- The workspace customer-managed key display name. All existing keys can be found using /"az synapse workspace key list/" cmdlet.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The workspace name.

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az synapse workspace key create", locals())


def delete(name, resource_group, workspace_name, no_wait=None, yes=None):
    '''
    Delete a workspace's key. The key at active status can't be deleted.

    Required Parameters:
    - name -- The workspace customer-managed key display name. All existing keys can be found using /"az synapse workspace key list/" cmdlet.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The workspace name.

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az synapse workspace key delete", locals())


def wait(key_name, resource_group, workspace_name, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of a workspace key is met.

    Required Parameters:
    - key_name -- The name of the workspace key.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The workspace name.

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - interval -- polling interval in seconds
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az synapse workspace key wait", locals())




from .... pyaz_utils import _call_az
from . import keys


def list(alias, namespace_name, resource_group):
    '''
    Shows the list of Authorization Rule by Service Bus Namespace

    Required Parameters:
    - alias -- Name of Geo-Disaster Recovery Configuration Alias
    - namespace_name -- Name of Namespace
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az servicebus georecovery-alias authorization-rule list", locals())


def show(alias, name, namespace_name, resource_group):
    '''
    

    Required Parameters:
    - alias -- Name of the Geo-Disaster Recovery Configuration Alias
    - name -- name of Namespace Authorization Rule
    - namespace_name -- Name of Namespace
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az servicebus georecovery-alias authorization-rule show", locals())




'''
Manage Batch service options for a subscription at the region level.
'''
from ... pyaz_utils import _call_az
from . import quotas


def list_skus(location, filter=None, maxresults=None):
    '''
    List virtual machine SKUs available in a location.

    Required Parameters:
    - location -- The region for which to display the available Batch VM SKUs.

    Optional Parameters:
    - filter -- OData filter expression. Valid properties for filtering are "familyName".
    - maxresults -- The maximum number of items to return in the response.
    '''
    return _call_az("az batch location list-skus", locals())




from ... pyaz_utils import _call_az

def create(gallery_image_definition, gallery_name, offer, os_type, publisher, resource_group, sku, description=None, disallowed_disk_types=None, end_of_life_date=None, eula=None, features=None, hyper_v_generation=None, location=None, maximum_cpu_core=None, maximum_memory=None, minimum_cpu_core=None, minimum_memory=None, os_state=None, plan_name=None, plan_product=None, plan_publisher=None, privacy_statement_uri=None, release_note_uri=None, tags=None):
    '''
    create a gallery image definition

    Required Parameters:
    - gallery_image_definition -- gallery image definition
    - gallery_name -- gallery name
    - offer -- image offer
    - os_type -- the type of the OS that is included in the disk if creating a VM from user-image or a specialized VHD
    - publisher -- image publisher
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - sku -- image sku

    Optional Parameters:
    - description -- the description of the gallery image definition
    - disallowed_disk_types -- disk types which would not work with the image, e.g., Standard_LRS
    - end_of_life_date -- the end of life date, e.g. '2020-12-31'
    - eula -- The Eula agreement for the gallery image
    - features -- A list of gallery image features. E.g. "IsSecureBootSupported=true IsMeasuredBootSupported=false"
    - hyper_v_generation -- The hypervisor generation of the Virtual Machine. Applicable to OS disks only.
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - maximum_cpu_core -- maximum cpu cores
    - maximum_memory -- maximum memory in MB
    - minimum_cpu_core -- minimum cpu cores
    - minimum_memory -- minimum memory in MB
    - os_state -- This property allows the user to specify whether the virtual machines created under this image are 'Generalized' or 'Specialized'.
    - plan_name -- plan name
    - plan_product -- plan product
    - plan_publisher -- plan publisher
    - privacy_statement_uri -- The privacy statement uri
    - release_note_uri -- The release note uri
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az sig image-definition create", locals())


def list(gallery_name, resource_group):
    '''
    

    Required Parameters:
    - gallery_name -- gallery name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az sig image-definition list", locals())


def show(gallery_image_definition, gallery_name, resource_group):
    '''
    

    Required Parameters:
    - gallery_image_definition -- gallery image definition
    - gallery_name -- gallery name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az sig image-definition show", locals())


def delete(gallery_image_definition, gallery_name, resource_group):
    '''
    

    Required Parameters:
    - gallery_image_definition -- gallery image definition
    - gallery_name -- gallery name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az sig image-definition delete", locals())


def update(gallery_image_definition, gallery_name, resource_group, add=None, force_string=None, remove=None, set=None):
    '''
    Update a VM Image definition.

    Required Parameters:
    - gallery_image_definition -- gallery image definition
    - gallery_name -- gallery name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    '''
    return _call_az("az sig image-definition update", locals())


def list_shared(gallery_unique_name, location, shared_to=None):
    '''
    List VM Image definitions in a gallery shared directly to your subscription or tenant (preview).

    Required Parameters:
    - gallery_unique_name -- The unique name of the Shared Gallery.
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.

    Optional Parameters:
    - shared_to -- The query parameter to decide what shared galleries to fetch when doing listing operations. If not specified, list by subscription id.
    '''
    return _call_az("az sig image-definition list-shared", locals())


def show_shared(gallery_image_definition, gallery_unique_name, location):
    '''
    Get a shared gallery image (preview).

    Required Parameters:
    - gallery_image_definition -- The name of the Shared Gallery Image Definition from which the Image Versions are to be listed.
    - gallery_unique_name -- The unique name of the Shared Gallery.
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    '''
    return _call_az("az sig image-definition show-shared", locals())




'''
Manage Azure EventHubs namespace and Authorizationrule
'''
from ... pyaz_utils import _call_az
from . import authorization_rule, network_rule, private_endpoint_connection, private_link_resource


def create(name, resource_group, assign_identity=None, capacity=None, cluster_arm_id=None, default_action=None, disable_local_auth=None, enable_auto_inflate=None, enable_kafka=None, enable_trusted_service_access=None, location=None, maximum_throughput_units=None, sku=None, tags=None, zone_redundant=None):
    '''
    Creates the EventHubs Namespace

    Required Parameters:
    - name -- Name of Namespace
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - assign_identity -- A boolean value that indicates whether Managed Identity is enabled.
    - capacity -- Capacity for Sku
    - cluster_arm_id -- luster ARM ID of the Namespace
    - default_action -- Default Action for Network Rule Set.
    - disable_local_auth -- A boolean value that indicates whether SAS authentication is enabled/disabled for the Event Hubs
    - enable_auto_inflate -- A boolean value that indicates whether AutoInflate is enabled for eventhub namespace.
    - enable_kafka -- A boolean value that indicates whether Kafka is enabled for eventhub namespace.
    - enable_trusted_service_access -- A boolean value that indicates whether Trusted Service Access is enabled for Network Rule Set.
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - maximum_throughput_units -- Upper limit of throughput units when AutoInflate is enabled, vaule should be within 0 to 20 throughput units. ( 0 if AutoInflateEnabled = true)
    - sku -- Namespace SKU.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - zone_redundant -- Enabling this property creates a Standard EventHubs Namespace in regions supported availability zones
    '''
    return _call_az("az eventhubs namespace create", locals())


def show(name, resource_group):
    '''
    shows the Event Hubs Namespace Details

    Required Parameters:
    - name -- Name of Namespace
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az eventhubs namespace show", locals())


def list(resource_group=None):
    '''
    Lists the EventHubs Namespaces

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az eventhubs namespace list", locals())


def delete(name, resource_group):
    '''
    Deletes the Namespaces

    Required Parameters:
    - name -- Name of Namespace
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az eventhubs namespace delete", locals())


def exists(name):
    '''
    check for the availability of the given name for the Namespace

    Required Parameters:
    - name -- Namespace name. Name can contain only letters, numbers, and hyphens. The namespace must start with a letter, and it must end with a letter or number.
    '''
    return _call_az("az eventhubs namespace exists", locals())


def update(name, resource_group, add=None, assign_identity=None, capacity=None, default_action=None, disable_local_auth=None, enable_auto_inflate=None, enable_kafka=None, enable_trusted_service_access=None, force_string=None, infra_encryption=None, key_name=None, key_source=None, key_vault_uri=None, key_version=None, maximum_throughput_units=None, remove=None, set=None, sku=None, tags=None):
    '''
    Updates the EventHubs Namespace

    Required Parameters:
    - name -- Name of Namespace
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - assign_identity -- A boolean value that indicates whether Managed Identity is enabled.
    - capacity -- Capacity for Sku
    - default_action -- Default Action for Network Rule Set.
    - disable_local_auth -- A boolean value that indicates whether SAS authentication is enabled/disabled for the Event Hubs
    - enable_auto_inflate -- A boolean value that indicates whether AutoInflate is enabled for eventhub namespace.
    - enable_kafka -- A boolean value that indicates whether Kafka is enabled for eventhub namespace.
    - enable_trusted_service_access -- A boolean value that indicates whether Trusted Service Access is enabled for Network Rule Set.
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - infra_encryption -- A boolean value that indicates whether Infrastructure Encryption (Double Encryption) is enabled/disabled
    - key_name -- The name of the KeyVault key.
    - key_source -- Encryption key source. Possible values include: 'Microsoft.KeyVault'.
    - key_vault_uri -- The Uri of the KeyVault.
    - key_version -- The version of the KeyVault key to use.
    - maximum_throughput_units -- Upper limit of throughput units when AutoInflate is enabled, vaule should be within 0 to 20 throughput units. ( 0 if AutoInflateEnabled = true)
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - sku -- Namespace SKU.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az eventhubs namespace update", locals())




'''
Manage Synapse Spark batch jobs.
'''
from .... pyaz_utils import _call_az

def submit(executor_size, executors, main_definition_file, name, spark_pool_name, workspace_name, archives=None, arguments=None, configuration=None, language=None, main_class_name=None, reference_files=None, tags=None):
    '''
    Submit a Spark job.

    Required Parameters:
    - executor_size -- The executor size
    - executors -- The number of executors.
    - main_definition_file -- The main file used for the job.
    - name -- The Spark job name.
    - spark_pool_name -- The name of the Spark pool.
    - workspace_name -- The name of the workspace.

    Optional Parameters:
    - archives -- The array of archives.
    - arguments -- Optional arguments to the job (Note: please use storage URIs for file arguments).
    - configuration -- The configuration of Spark job.
    - language -- The Spark job language.
    - main_class_name -- The fully-qualified identifier or the main class that is in the main definition file.
    - reference_files -- Additional files used for reference in the main definition file.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az synapse spark job submit", locals())


def list(spark_pool_name, workspace_name, from_index=None, size=None):
    '''
    List all Spark jobs.

    Required Parameters:
    - spark_pool_name -- The name of the Spark pool.
    - workspace_name -- The name of the workspace.

    Optional Parameters:
    - from_index -- Optional parameter specifying which index the list should begin from.
    - size -- The size of the returned list.By default it is 20 and that is the maximum.
    '''
    return _call_az("az synapse spark job list", locals())


def show(livy_id, spark_pool_name, workspace_name):
    '''
    Get a Spark job.

    Required Parameters:
    - livy_id -- The id of the Spark job.
    - spark_pool_name -- The name of the Spark pool.
    - workspace_name -- The name of the workspace.
    '''
    return _call_az("az synapse spark job show", locals())


def cancel(livy_id, spark_pool_name, workspace_name, yes=None):
    '''
    Cancel a Spark job.

    Required Parameters:
    - livy_id -- The id of the Spark job.
    - spark_pool_name -- The name of the Spark pool.
    - workspace_name -- The name of the workspace.

    Optional Parameters:
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az synapse spark job cancel", locals())




'''
A snapshot of data at that point-of-time, stored in Recovery Services Vault, from which you can restore information.
'''
from ... pyaz_utils import _call_az

def show(container_name, item_name, name, resource_group, vault_name, backup_management_type=None, use_secondary_region=None, workload_type=None):
    '''
    Shows details of a particular recovery point.

    Required Parameters:
    - container_name -- Name of the backup container. Accepts 'Name' or 'FriendlyName' from the output of az backup container list command. If 'FriendlyName' is passed then BackupManagementType is required.
    - item_name -- Name of the backed up item.
    - name -- Name of the recovery point. You can use the backup recovery point list command to get the name of a backed up item.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vault_name -- Name of the Recovery services vault.

    Optional Parameters:
    - backup_management_type -- Specify the backup management type. Define how Azure Backup manages the backup of entities within the ARM resource. For eg: AzureWorkloads refers to workloads installed within Azure VMs, AzureStorage refers to entities within Storage account. Required only if friendly name is used as Container name.
    - use_secondary_region -- Use this flag to show recoverypoints in secondary region.
    - workload_type -- Specify the type of applications within the Resource which should be discovered and protected by Azure Backup. 
    '''
    return _call_az("az backup recoverypoint show", locals())


def list(container_name, item_name, resource_group, vault_name, backup_management_type=None, end_date=None, is_ready_for_move=None, recommended_for_archive=None, start_date=None, target_tier=None, tier=None, use_secondary_region=None, workload_type=None):
    '''
    List all recovery points of a backed up item.

    Required Parameters:
    - container_name -- Name of the backup container. Accepts 'Name' or 'FriendlyName' from the output of az backup container list command. If 'FriendlyName' is passed then BackupManagementType is required.
    - item_name -- Name of the backed up item.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vault_name -- Name of the Recovery services vault.

    Optional Parameters:
    - backup_management_type -- Specify the backup management type. Define how Azure Backup manages the backup of entities within the ARM resource. For eg: AzureWorkloads refers to workloads installed within Azure VMs, AzureStorage refers to entities within Storage account. Required only if friendly name is used as Container name.
    - end_date -- The end date of the range in UTC (d-m-Y).
    - is_ready_for_move -- Use this flag to retrieve the recoverypoints that are ready to be moved to destination-tier.
    - recommended_for_archive -- Use this flag to retrieve recommended archivable recoverypoints.
    - start_date -- The start date of the range in UTC (d-m-Y).
    - target_tier --  The destination/target tier to which a particular recovery point has to be moved.
    - tier --  Provide 'tier' parameter to filter recovery points.
    - use_secondary_region -- Use this flag to list recoverypoints in secondary region.
    - workload_type -- Specify the type of applications within the Resource which should be discovered and protected by Azure Backup. 
    '''
    return _call_az("az backup recoverypoint list", locals())


def move(container_name, destination_tier, item_name, name, resource_group, source_tier, vault_name, backup_management_type=None, workload_type=None):
    '''
    Move a particular recovery point of a backed up item from one tier to another tier.

    Required Parameters:
    - container_name -- Name of the backup container. Accepts 'Name' or 'FriendlyName' from the output of az backup container list command. If 'FriendlyName' is passed then BackupManagementType is required.
    - destination_tier --  The destination/target tier to which a particular recovery point has to be moved.
    - item_name -- Name of the backed up item.
    - name -- Name of the recovery point.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - source_tier -- The source tier from which a particular recovery point has to be moved.
    - vault_name -- Name of the Recovery services vault.

    Optional Parameters:
    - backup_management_type -- Specify the backup management type. Define how Azure Backup manages the backup of entities within the ARM resource. For eg: AzureWorkloads refers to workloads installed within Azure VMs, AzureStorage refers to entities within Storage account. Required only if friendly name is used as Container name.
    - workload_type -- Specify the type of applications within the Resource which should be discovered and protected by Azure Backup. 
    '''
    return _call_az("az backup recoverypoint move", locals())


def show_log_chain(container_name, item_name, resource_group, vault_name, backup_management_type=None, end_date=None, start_date=None, use_secondary_region=None, workload_type=None):
    '''
    List the start and end points of the unbroken log chain(s) of the given backup item.

    Required Parameters:
    - container_name -- Name of the backup container. Accepts 'Name' or 'FriendlyName' from the output of az backup container list command. If 'FriendlyName' is passed then BackupManagementType is required.
    - item_name -- Name of the backed up item.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vault_name -- Name of the Recovery services vault.

    Optional Parameters:
    - backup_management_type -- Specify the backup management type. Define how Azure Backup manages the backup of entities within the ARM resource. For eg: AzureWorkloads refers to workloads installed within Azure VMs, AzureStorage refers to entities within Storage account. Required only if friendly name is used as Container name.
    - end_date -- The end date of the range in UTC (d-m-Y).
    - start_date -- The start date of the range in UTC (d-m-Y).
    - use_secondary_region -- Use this flag to list recoverypoints in secondary region.
    - workload_type -- Specify the type of applications within the Resource which should be discovered and protected by Azure Backup. 
    '''
    return _call_az("az backup recoverypoint show-log-chain", locals())




from ... pyaz_utils import _call_az

def set_key(hybrid_connection, key_type, namespace, plan, resource_group):
    '''
    set the key that all apps in an appservice plan use to connect to the hybrid-connections in that appservice plan

    Required Parameters:
    - hybrid_connection -- Hybrid connection name
    - key_type -- Which key (primary or secondary) should be used
    - namespace -- Hybrid connection namespace
    - plan -- AppService plan
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az appservice hybrid-connection set-key", locals())




'''
Manage Microsoft Azure Bot Service.
'''
from .. pyaz_utils import _call_az
from . import authsetting, directline, email, facebook, kik, msteams, skype, slack, sms, telegram, webchat


def create(appid, kind, name, resource_group, cmk_key_vault_key_url=None, description=None, display_name=None, echo=None, lang=None, location=None, sku=None, tags=None):
    '''
    Create a new v4 SDK bot.

    Required Parameters:
    - appid -- The Microsoft account ID (MSA ID) to be used with the bot.
    - kind -- The kind of the bot.
    - name -- The resource name of the bot. Bot name must be between 4 and 42 characters in length. Bot name can only have the following characters -, a - z, A - Z, 0 - 9, and _.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - cmk_key_vault_key_url -- The key vault key url to enable Customer Managed Keys encryption
    - description -- The description of the bot.
    - display_name -- The display name of the bot. If not specified, defaults to the name of the bot.
    - echo -- Deploy an Echo Bot template to the newly created v4 Web App Bot.
    - lang -- The language to be used to create the bot.
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - sku -- The Sku of the bot.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az bot create", locals())


def publish(name, resource_group, code_dir=None, keep_node_modules=None, proj_file_path=None, timeout=None):
    '''
    Publish to a bot's associated app service.

    Required Parameters:
    - name -- The resource name of the bot. Bot name must be between 4 and 42 characters in length. Bot name can only have the following characters -, a - z, A - Z, 0 - 9, and _.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - code_dir -- The directory to upload bot code from.
    - keep_node_modules -- Keep node_modules folder and do not run `npm install` on the App Service. This can greatly speed up publish commands for Node.js SDK bots.
    - proj_file_path -- Path to the start up project file name. (E.g. "./EchoBotWithCounter.csproj")
    - timeout -- Configurable timeout in seconds for checking the status of deployment.
    '''
    return _call_az("az bot publish", locals())


def download(name, resource_group, save_path=None):
    '''
    Download an existing bot.

    Required Parameters:
    - name -- The resource name of the bot. Bot name must be between 4 and 42 characters in length. Bot name can only have the following characters -, a - z, A - Z, 0 - 9, and _.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - save_path -- The directory to download bot code to.
    '''
    return _call_az("az bot download", locals())


def prepare_publish(name, proj_file_path, resource_group, sln_name, code_dir=None):
    '''
    (Maintenance mode) Add scripts to your local source code directory to be able to publish back using `az bot publish` for v3 SDK bots.

    Required Parameters:
    - name -- The resource name of the bot. Bot name must be between 4 and 42 characters in length. Bot name can only have the following characters -, a - z, A - Z, 0 - 9, and _.
    - proj_file_path -- Path to the start up project file name. (E.g. "./EchoBotWithCounter.csproj") Required only for C#.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - sln_name -- Name of the start up solution file name. Required only for C#.

    Optional Parameters:
    - code_dir -- The directory to download deployment scripts to.
    '''
    return _call_az("az bot prepare-publish", locals())


def prepare_deploy(lang, code_dir=None, proj_file_path=None):
    '''
    Add scripts/config files for publishing with `az webapp deployment`.

    Required Parameters:
    - lang -- The language or runtime of the bot.

    Optional Parameters:
    - code_dir -- The directory to place the generated deployment files in. Defaults to the current directory the command is called from.
    - proj_file_path -- The path to the .csproj file relative to --code-dir.
    '''
    return _call_az("az bot prepare-deploy", locals())


def show(name, resource_group, msbot=None):
    '''
    Get an existing bot.

    Required Parameters:
    - name -- The resource name of the bot. Bot name must be between 4 and 42 characters in length. Bot name can only have the following characters -, a - z, A - Z, 0 - 9, and _.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - msbot -- Show the output as JSON compatible with a .bot file.
    '''
    return _call_az("az bot show", locals())


def delete(name, resource_group):
    '''
    Delete an existing bot.

    Required Parameters:
    - name -- The resource name of the bot. Bot name must be between 4 and 42 characters in length. Bot name can only have the following characters -, a - z, A - Z, 0 - 9, and _.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az bot delete", locals())


def update(name, resource_group, app_insights_api_key=None, app_insights_app_id=None, app_insights_key=None, cmk_key_vault_key_url=None, cmk_off=None, description=None, display_name=None, endpoint=None, icon_url=None, sku=None, tags=None):
    '''
    Update an existing bot.

    Required Parameters:
    - name -- The resource name of the bot. Bot name must be between 4 and 42 characters in length. Bot name can only have the following characters -, a - z, A - Z, 0 - 9, and _.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - app_insights_api_key -- Azure Application Insights API Key used to read bot analytics data. Provide a key if you want to view analytics about your bot in the Analytics blade.
    - app_insights_app_id -- Azure Application Insights Application ID used to read bot analytics data. Provide an Id if you want to view analytics about your bot in the Analytics blade.
    - app_insights_key -- Azure Application Insights Key used to write bot analytics data. Provide a key if you want to receive bot analytics.
    - cmk_key_vault_key_url -- The key vault key url to enable Customer Managed Keys encryption
    - cmk_off -- Set encryption to Microsoft-Managed Keys
    - description -- The bot's new description.
    - display_name -- The bot's new display name.
    - endpoint -- The new endpoint of the bot. Must start with "https://"
    - icon_url -- Icon URL for bot avatar. Accepts PNG files with file size limit of 30KB.
    - sku -- The Sku of the bot.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az bot update", locals())




from .... pyaz_utils import _call_az

def show(name, resource_group, server):
    '''
    

    Required Parameters:
    - name -- Name of the DNS alias.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`
    '''
    return _call_az("az sql server dns-alias show", locals())


def list(resource_group, server):
    '''
    

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`
    '''
    return _call_az("az sql server dns-alias list", locals())


def create(name, resource_group, server):
    '''
    

    Required Parameters:
    - name -- Name of the DNS alias.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`
    '''
    return _call_az("az sql server dns-alias create", locals())


def delete(name, resource_group, server):
    '''
    

    Required Parameters:
    - name -- Name of the DNS alias.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`
    '''
    return _call_az("az sql server dns-alias delete", locals())


def set(name, original_server, resource_group, server, original_resource_group=None, original_subscription_id=None):
    '''
    Sets a server to which DNS alias should point

    Required Parameters:
    - name -- Name of the DNS alias.
    - original_server -- The name of the server to which alias is currently pointing
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`

    Optional Parameters:
    - original_resource_group -- Name of the original resource group.
    - original_subscription_id -- ID of the original subscription.
    '''
    return _call_az("az sql server dns-alias set", locals())




'''
View Azure resource metrics.
'''
from ... pyaz_utils import _call_az
from . import alert


def list(resource, aggregation=None, dimension=None, end_time=None, filter=None, interval=None, metadata=None, metrics=None, namespace=None, offset=None, orderby=None, resource_group=None, resource_namespace=None, resource_parent=None, resource_type=None, start_time=None, top=None):
    '''
    List the metric values for a resource.

    Required Parameters:
    - resource -- Name or ID of the target resource.

    Optional Parameters:
    - aggregation -- None
    - dimension -- None
    - end_time -- End time of the query. Defaults to the current time. Format: date (yyyy-mm-dd) time (hh:mm:ss.xxxxx) timezone (+/-hh:mm)
    - filter -- None
    - interval -- None
    - metadata -- None
    - metrics -- None
    - namespace -- None
    - offset -- None
    - orderby -- Aggregation to use for sorting results and the direction of the sort. Only one order can be specificed. Examples: sum asc
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - resource_namespace -- Target resource provider namespace.
    - resource_parent -- Target resource parent path, if applicable.
    - resource_type -- Target resource type. Can also accept namespace/type format (Ex: 'Microsoft.Compute/virtualMachines')
    - start_time -- Start time of the query. Format: date (yyyy-mm-dd) time (hh:mm:ss.xxxxx) timezone (+/-hh:mm)
    - top -- Max number of records to retrieve. Valid only if --filter used.
    '''
    return _call_az("az monitor metrics list", locals())


def list_definitions(resource, namespace=None, resource_group=None, resource_namespace=None, resource_parent=None, resource_type=None):
    '''
    List the metric definitions for the resource.

    Required Parameters:
    - resource -- Name or ID of the target resource.

    Optional Parameters:
    - namespace -- Namespace to query metric definitions for.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - resource_namespace -- Target resource provider namespace.
    - resource_parent -- Target resource parent path, if applicable.
    - resource_type -- Target resource type. Can also accept namespace/type format (Ex: 'Microsoft.Compute/virtualMachines')
    '''
    return _call_az("az monitor metrics list-definitions", locals())


def list_namespaces(resource_uri, start_time=None):
    '''
    List the metric namespaces for the resource.

    Required Parameters:
    - resource_uri -- The identifier of the resource.

    Optional Parameters:
    - start_time -- Start time of the query. Format: date (yyyy-mm-dd) time (hh:mm:ss.xxxxx) timezone (+/-hh:mm)
    '''
    return _call_az("az monitor metrics list-namespaces", locals())




'''
Commands to manage webapp connections
'''
from ... pyaz_utils import _call_az
from . import create, update


def list(name=None, resource_group=None, source_id=None):
    '''
    List connections of a webapp.

    Optional Parameters:
    - name -- Name of the webapp. Required if '--source-id' is not specified.
    - resource_group -- The resource group which contains the webapp. Required if '--source-id' is not specified.
    - source_id -- The resource id of a webapp. Required if ['--resource-group', '--name'] are not specified.
    '''
    return _call_az("az webapp connection list", locals())


def show(connection=None, id=None, name=None, resource_group=None):
    '''
    Get the details of a webapp connection.

    Optional Parameters:
    - connection -- Name of the webapp connection.
    - id -- The resource id of the connection. ['--resource-group', '--name', '--connection'] are required if '--id' is not specified.
    - name -- Name of the webapp. Required if '--source-id' is not specified.
    - resource_group -- The resource group which contains the webapp. Required if '--source-id' is not specified.
    '''
    return _call_az("az webapp connection show", locals())


def delete(connection=None, id=None, name=None, no_wait=None, resource_group=None, yes=None):
    '''
    Delete a webapp connection.

    Optional Parameters:
    - connection -- Name of the webapp connection.
    - id -- The resource id of the connection. ['--resource-group', '--name', '--connection'] are required if '--id' is not specified.
    - name -- Name of the webapp. Required if '--source-id' is not specified.
    - no_wait -- Do not wait for the long-running operation to finish.
    - resource_group -- The resource group which contains the webapp. Required if '--source-id' is not specified.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az webapp connection delete", locals())


def list_configuration(connection=None, id=None, name=None, resource_group=None):
    '''
    List source configurations of a webapp connection.

    Optional Parameters:
    - connection -- Name of the webapp connection.
    - id -- The resource id of the connection. ['--resource-group', '--name', '--connection'] are required if '--id' is not specified.
    - name -- Name of the webapp. Required if '--source-id' is not specified.
    - resource_group -- The resource group which contains the webapp. Required if '--source-id' is not specified.
    '''
    return _call_az("az webapp connection list-configuration", locals())


def validate(connection=None, id=None, name=None, resource_group=None):
    '''
    Validate a webapp connection.

    Optional Parameters:
    - connection -- Name of the webapp connection.
    - id -- The resource id of the connection. ['--resource-group', '--name', '--connection'] are required if '--id' is not specified.
    - name -- Name of the webapp. Required if '--source-id' is not specified.
    - resource_group -- The resource group which contains the webapp. Required if '--source-id' is not specified.
    '''
    return _call_az("az webapp connection validate", locals())


def list_support_types(target_type=None):
    '''
    List client types and auth types supported by webapp connections.

    Optional Parameters:
    - target_type -- The target resource type
    '''
    return _call_az("az webapp connection list-support-types", locals())


def wait(connection=None, created=None, custom=None, deleted=None, exists=None, id=None, interval=None, name=None, resource_group=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the connection is met.

    Optional Parameters:
    - connection -- Name of the webapp connection.
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - id -- The resource id of the connection. ['--resource-group', '--name', '--connection'] are required if '--id' is not specified.
    - interval -- polling interval in seconds
    - name -- Name of the webapp. Required if '--source-id' is not specified.
    - resource_group -- The resource group which contains the webapp. Required if '--source-id' is not specified.
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az webapp connection wait", locals())




'''
Manage Azure Billing.
'''
from .. pyaz_utils import _call_az
from . import account, agreement, balance, customer, enrollment_account, instruction, invoice, period, permission, policy, product, profile, property, role_assignment, role_definition, subscription, transaction




'''
Manage network interfaces of a VMSS.
'''
from ... pyaz_utils import _call_az

def list(resource_group, vmss_name):
    '''
    

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vmss_name -- Scale set name. You can configure the default using `az configure --defaults vmss=<name>`
    '''
    return _call_az("az vmss nic list", locals())


def list_vm_nics(instance_id, resource_group, vmss_name):
    '''
    

    Required Parameters:
    - instance_id -- The virtual machine index.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vmss_name -- Scale set name.
    '''
    return _call_az("az vmss nic list-vm-nics", locals())


def show(instance_id, name, resource_group, vmss_name, expand=None):
    '''
    

    Required Parameters:
    - instance_id -- The virtual machine index.
    - name -- The network interface (NIC).
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vmss_name -- Scale set name.

    Optional Parameters:
    - expand -- Expands referenced resources.
    '''
    return _call_az("az vmss nic show", locals())




'''
Manage storage accounts.
'''
from ... pyaz_utils import _call_az
from . import blob_inventory_policy, blob_service_properties, encryption_scope, file_service_properties, hns_migration, keys, management_policy, network_rule, or_policy, private_endpoint_connection, private_link_resource


def check_name(name):
    '''
    Check that the storage account name is valid and is not already in use.

    Required Parameters:
    - name -- The name of the storage account within the specified resource group
    '''
    return _call_az("az storage account check-name", locals())


def create(name, resource_group, access_tier=None, action=None, allow_blob_public_access=None, allow_cross_tenant_replication=None, allow_protected_append_writes=None, allow_shared_key_access=None, assign_identity=None, azure_storage_sid=None, bypass=None, custom_domain=None, default_action=None, default_share_permission=None, domain_guid=None, domain_name=None, domain_sid=None, edge_zone=None, enable_alw=None, enable_files_aadds=None, enable_files_adds=None, enable_hierarchical_namespace=None, enable_large_file_share=None, enable_nfs_v3=None, encryption_key_name=None, encryption_key_source=None, encryption_key_type_for_queue=None, encryption_key_type_for_table=None, encryption_key_vault=None, encryption_key_version=None, encryption_services=None, forest_name=None, https_only=None, identity_type=None, immutability_period_in_days=None, immutability_state=None, key_expiration_period_in_days=None, key_vault_user_identity_id=None, kind=None, location=None, min_tls_version=None, net_bios_domain_name=None, public_network_access=None, publish_internet_endpoints=None, publish_microsoft_endpoints=None, require_infrastructure_encryption=None, routing_choice=None, sas_expiration_period=None, sku=None, subnet=None, tags=None, user_identity_id=None, vnet_name=None):
    '''
    Create a storage account.

    Required Parameters:
    - name -- The storage account name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - access_tier -- The access tier used for billing StandardBlob accounts. Cannot be set for StandardLRS, StandardGRS, StandardRAGRS, or PremiumLRS account types. It is required for StandardBlob accounts during creation
    - action -- The action of virtual network rule. Possible value is Allow.
    - allow_blob_public_access -- Allow or disallow public access to all blobs or containers in the storage account. The default value for this property is null, which is equivalent to true. When true, containers in the account may be configured for public access. Note that setting this property to true does not enable anonymous access to any data in the account. The additional step of configuring the public access setting for a container is required to enable anonymous access.
    - allow_cross_tenant_replication -- Allow or disallow cross AAD tenant object replication. The default interpretation is true for this property.
    - allow_protected_append_writes -- This property can only be changed for disabled and unlocked time-based retention policies. When enabled, new blocks can be written to an append blob while maintaining immutability protection and compliance. Only new blocks can be added and any existing blocks cannot be modified or deleted.
    - allow_shared_key_access -- Indicate whether the storage account permits requests to be authorized with the account access key via Shared Key. If false, then all requests, including shared access signatures, must be authorized with Azure Active Directory (Azure AD). The default value is null, which is equivalent to true.
    - assign_identity -- Generate and assign a new Storage Account Identity for this storage account for use with key management services like Azure KeyVault.
    - azure_storage_sid -- Specify the security identifier (SID) for Azure Storage. Required when --enable-files-adds is set to True
    - bypass -- Bypass traffic for space-separated uses.
    - custom_domain -- User domain assigned to the storage account. Name is the CNAME source.
    - default_action -- Default action to apply when no rule matches.
    - default_share_permission -- Default share permission for users using Kerberos authentication if RBAC role is not assigned.
    - domain_guid -- Specify the domain GUID. Required when --enable-files-adds is set to True
    - domain_name -- Specify the primary domain that the AD DNS server is authoritative for. Required when --enable-files-adds is set to True
    - domain_sid -- Specify the security identifier (SID). Required when --enable-files-adds is set to True
    - edge_zone -- The name of edge zone.
    - enable_alw -- The account level immutability property. The property is immutable and can only be set to true at the account creation time. When set to true, it enables object level immutability for all the containers in the account by default.
    - enable_files_aadds -- Enable Azure Active Directory Domain Services authentication for Azure Files
    - enable_files_adds -- Enable Azure Files Active Directory Domain Service Authentication for storage account. When --enable-files-adds is set to true, Azure Active Directory Properties arguments must be provided.
    - enable_hierarchical_namespace --  Allow the blob service to exhibit filesystem semantics. This property can be enabled only when storage account kind is StorageV2.
    - enable_large_file_share -- Enable the capability to support large file shares with more than 5 TiB capacity for storage account.Once the property is enabled, the feature cannot be disabled. Currently only supported for LRS and ZRS replication types, hence account conversions to geo-redundant accounts would not be possible. For more information, please refer to https://go.microsoft.com/fwlink/?linkid=2086047.
    - enable_nfs_v3 -- NFS 3.0 protocol support enabled if sets to true.
    - encryption_key_name -- The name of the KeyVault key.
    - encryption_key_source -- The default encryption key source
    - encryption_key_type_for_queue -- Set the encryption key type for Queue service. "Account": Queue will be encrypted with account-scoped encryption key. "Service": Queue will always be encrypted with service-scoped keys. Currently the default encryption key type is "Service".
    - encryption_key_type_for_table -- Set the encryption key type for Table service. "Account": Table will be encrypted with account-scoped encryption key. "Service": Table will always be encrypted with service-scoped keys. Currently the default encryption key type is "Service".
    - encryption_key_vault -- The Uri of the KeyVault.
    - encryption_key_version -- The version of the KeyVault key to use, which will opt out of implicit key rotation. Please use "" to opt in key auto-rotation again.
    - encryption_services -- Specifies which service(s) to encrypt.
    - forest_name -- Specify the Active Directory forest to get. Required when --enable-files-adds is set to True
    - https_only -- Allow https traffic only to storage service if set to true. The default value is true.
    - identity_type -- The identity type.
    - immutability_period_in_days -- The immutability period for the blobs in the container since the policy creation, in days.
    - immutability_state -- Defines the mode of the policy. Disabled state disables the policy, Unlocked state allows increase and decrease of immutability retention time and also allows toggling allow-protected-append-write property, Locked state only allows the increase of the immutability retention time. A policy can only be created in a Disabled or Unlocked state and can be toggled between the two states. Only a policy in an Unlocked state can transition to a Locked state which cannot be reverted.
    - key_expiration_period_in_days -- Expiration period in days of the Key Policy assigned to the storage account
    - key_vault_user_identity_id -- Resource identifier of the UserAssigned identity to be associated with server-side encryption on the storage account.
    - kind -- Indicate the type of storage account.
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - min_tls_version -- The minimum TLS version to be permitted on requests to storage. The default interpretation is TLS 1.0 for this property
    - net_bios_domain_name -- Specify the NetBIOS domain name. Required when --enable-files-adds is set to True
    - public_network_access -- Enable or disable public network access to the storage account. Possible values include: `Enabled` or `Disabled`.
    - publish_internet_endpoints -- A boolean flag which indicates whether internet routing storage endpoints are to be published.
    - publish_microsoft_endpoints -- A boolean flag which indicates whether microsoft routing storage endpoints are to be published.
    - require_infrastructure_encryption -- A boolean indicating whether or not the service applies a secondary layer of encryption with platform managed keys for data at rest.
    - routing_choice -- Routing Choice defines the kind of network routing opted by the user.
    - sas_expiration_period -- Expiration period of the SAS Policy assigned to the storage account, DD.HH:MM:SS.
    - sku -- The storage account SKU.
    - subnet -- Name or ID of subnet. If name is supplied, `--vnet-name` must be supplied.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - user_identity_id -- The key is the ARM resource identifier of the identity. Only 1 User Assigned identity is permitted here.
    - vnet_name -- Name of a virtual network.
    '''
    return _call_az("az storage account create", locals())


def delete(name, resource_group=None, yes=None):
    '''
    Delete a storage account.

    Required Parameters:
    - name -- The storage account name.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az storage account delete", locals())


def show(name, expand=None, resource_group=None):
    '''
    Show storage account properties.

    Required Parameters:
    - name -- The storage account name.

    Optional Parameters:
    - expand -- May be used to expand the properties within account's properties. By default, data is not included when fetching properties. Currently we only support geoReplicationStats and blobRestoreStatus.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az storage account show", locals())


def list(resource_group=None):
    '''
    List storage accounts.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az storage account list", locals())


def show_usage(location):
    '''
    Show the current count and limit of the storage accounts under the subscription.

    Required Parameters:
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    '''
    return _call_az("az storage account show-usage", locals())


def show_connection_string(name, blob_endpoint=None, file_endpoint=None, key=None, protocol=None, queue_endpoint=None, resource_group=None, sas_token=None, table_endpoint=None):
    '''
    Get the connection string for a storage account.

    Required Parameters:
    - name -- The storage account name.

    Optional Parameters:
    - blob_endpoint -- Custom endpoint for blobs.
    - file_endpoint -- Custom endpoint for files.
    - key -- The key to use.
    - protocol -- The default endpoint protocol.
    - queue_endpoint -- Custom endpoint for queues.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - sas_token -- The SAS token to be used in the connection-string.
    - table_endpoint -- Custom endpoint for tables.
    '''
    return _call_az("az storage account show-connection-string", locals())


def update(name, access_tier=None, add=None, allow_blob_public_access=None, allow_cross_tenant_replication=None, allow_protected_append_writes=None, allow_shared_key_access=None, assign_identity=None, azure_storage_sid=None, bypass=None, custom_domain=None, default_action=None, default_share_permission=None, domain_guid=None, domain_name=None, domain_sid=None, enable_files_aadds=None, enable_files_adds=None, enable_large_file_share=None, encryption_key_name=None, encryption_key_source=None, encryption_key_vault=None, encryption_key_version=None, encryption_services=None, force_string=None, forest_name=None, https_only=None, identity_type=None, immutability_period_in_days=None, immutability_state=None, key_expiration_period_in_days=None, key_vault_user_identity_id=None, min_tls_version=None, net_bios_domain_name=None, public_network_access=None, publish_internet_endpoints=None, publish_microsoft_endpoints=None, remove=None, resource_group=None, routing_choice=None, sas_expiration_period=None, set=None, sku=None, tags=None, use_subdomain=None, user_identity_id=None):
    '''
    Update the properties of a storage account.

    Required Parameters:
    - name -- The storage account name.

    Optional Parameters:
    - access_tier -- The access tier used for billing StandardBlob accounts. Cannot be set for StandardLRS, StandardGRS, StandardRAGRS, or PremiumLRS account types. It is required for StandardBlob accounts during creation
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - allow_blob_public_access -- Allow or disallow public access to all blobs or containers in the storage account. The default value for this property is null, which is equivalent to true. When true, containers in the account may be configured for public access. Note that setting this property to true does not enable anonymous access to any data in the account. The additional step of configuring the public access setting for a container is required to enable anonymous access.
    - allow_cross_tenant_replication -- Allow or disallow cross AAD tenant object replication. The default interpretation is true for this property.
    - allow_protected_append_writes -- This property can only be changed for disabled and unlocked time-based retention policies. When enabled, new blocks can be written to an append blob while maintaining immutability protection and compliance. Only new blocks can be added and any existing blocks cannot be modified or deleted.
    - allow_shared_key_access -- Indicate whether the storage account permits requests to be authorized with the account access key via Shared Key. If false, then all requests, including shared access signatures, must be authorized with Azure Active Directory (Azure AD). The default value is null, which is equivalent to true.
    - assign_identity -- Generate and assign a new Storage Account Identity for this storage account for use with key management services like Azure KeyVault.
    - azure_storage_sid -- Specify the security identifier (SID) for Azure Storage. Required when --enable-files-adds is set to True
    - bypass -- Bypass traffic for space-separated uses.
    - custom_domain -- User domain assigned to the storage account. Name is the CNAME source. Use "" to clear existing value.
    - default_action -- Default action to apply when no rule matches.
    - default_share_permission -- Default share permission for users using Kerberos authentication if RBAC role is not assigned.
    - domain_guid -- Specify the domain GUID. Required when --enable-files-adds is set to True
    - domain_name -- Specify the primary domain that the AD DNS server is authoritative for. Required when --enable-files-adds is set to True
    - domain_sid -- Specify the security identifier (SID). Required when --enable-files-adds is set to True
    - enable_files_aadds -- Enable Azure Active Directory Domain Services authentication for Azure Files
    - enable_files_adds -- Enable Azure Files Active Directory Domain Service Authentication for storage account. When --enable-files-adds is set to true, Azure Active Directory Properties arguments must be provided.
    - enable_large_file_share -- Enable the capability to support large file shares with more than 5 TiB capacity for storage account.Once the property is enabled, the feature cannot be disabled. Currently only supported for LRS and ZRS replication types, hence account conversions to geo-redundant accounts would not be possible. For more information, please refer to https://go.microsoft.com/fwlink/?linkid=2086047.
    - encryption_key_name -- The name of the KeyVault key.
    - encryption_key_source -- The default encryption key source
    - encryption_key_vault -- The Uri of the KeyVault.
    - encryption_key_version -- The version of the KeyVault key to use, which will opt out of implicit key rotation. Please use "" to opt in key auto-rotation again.
    - encryption_services -- Specifies which service(s) to encrypt.
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - forest_name -- Specify the Active Directory forest to get. Required when --enable-files-adds is set to True
    - https_only -- Allows https traffic only to storage service.
    - identity_type -- The identity type.
    - immutability_period_in_days -- The immutability period for the blobs in the container since the policy creation, in days.
    - immutability_state -- Defines the mode of the policy. Disabled state disables the policy, Unlocked state allows increase and decrease of immutability retention time and also allows toggling allow-protected-append-write property, Locked state only allows the increase of the immutability retention time. A policy can only be created in a Disabled or Unlocked state and can be toggled between the two states. Only a policy in an Unlocked state can transition to a Locked state which cannot be reverted.
    - key_expiration_period_in_days -- Expiration period in days of the Key Policy assigned to the storage account
    - key_vault_user_identity_id -- Resource identifier of the UserAssigned identity to be associated with server-side encryption on the storage account.
    - min_tls_version -- The minimum TLS version to be permitted on requests to storage. The default interpretation is TLS 1.0 for this property
    - net_bios_domain_name -- Specify the NetBIOS domain name. Required when --enable-files-adds is set to True
    - public_network_access -- Enable or disable public network access to the storage account. Possible values include: `Enabled` or `Disabled`.
    - publish_internet_endpoints -- A boolean flag which indicates whether internet routing storage endpoints are to be published.
    - publish_microsoft_endpoints -- A boolean flag which indicates whether microsoft routing storage endpoints are to be published.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - routing_choice -- Routing Choice defines the kind of network routing opted by the user.
    - sas_expiration_period -- Expiration period of the SAS Policy assigned to the storage account, DD.HH:MM:SS.
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - sku -- Note that the SKU name cannot be updated to Standard_ZRS, Premium_LRS or Premium_ZRS, nor can accounts of those SKU names be updated to any other value
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - use_subdomain -- Specify whether to use indirect CNAME validation.
    - user_identity_id -- The key is the ARM resource identifier of the identity. Only 1 User Assigned identity is permitted here.
    '''
    return _call_az("az storage account update", locals())


def failover(name, no_wait=None, resource_group=None, yes=None):
    '''
    Failover request can be triggered for a storage account in case of availability issues.

    Required Parameters:
    - name -- The storage account name.

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az storage account failover", locals())


def revoke_delegation_keys(name, resource_group=None):
    '''
    Revoke all user delegation keys for a storage account.

    Required Parameters:
    - name -- The storage account name.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az storage account revoke-delegation-keys", locals())


def generate_sas(expiry, permissions, resource_types, services, account_key=None, account_name=None, connection_string=None, https_only=None, ip=None, start=None):
    '''
    Generate a shared access signature for the storage account.

    Required Parameters:
    - expiry -- None
    - permissions -- The permissions the SAS grants. Allowed values: (a)dd (c)reate (d)elete (l)ist (p)rocess (r)ead (u)pdate (w)rite (a)dd (c)reate (d)elete (l)ist (p)rocess (r)ead (u)pdate (w)rite. Can be combined.
    - resource_types -- None
    - services -- None

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- The storage account name.
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - https_only -- Only permit requests made with the HTTPS protocol. If omitted, requests from both the HTTP and HTTPS protocol are permitted.
    - ip -- Specifies the IP address or range of IP addresses from which to accept requests. Supports only IPv4 style addresses.
    - start -- None
    '''
    return _call_az("az storage account generate-sas", locals())




from .... pyaz_utils import _call_az

def delete(id=None, name=None, namespace_name=None, resource_group=None, yes=None):
    '''
    Delete a private endpoint connection request for eventhubs namespace.

    Optional Parameters:
    - id -- The ID of the private endpoint connection associated with the EventHubs Namespace. You can get it using `az eventhubs namespace show`.
    - name -- The name of the private endpoint connection associated with the EventHubs Namespace.
    - namespace_name -- The eventhubs namesapce name.
    - resource_group -- The resource group name of specified eventhubs namespace.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az eventhubs namespace private-endpoint-connection delete", locals())


def show(id=None, name=None, namespace_name=None, resource_group=None):
    '''
    Show details of a private endpoint connection request for eventhubs namespace.

    Optional Parameters:
    - id -- The ID of the private endpoint connection associated with the EventHubs Namespace. You can get it using `az eventhubs namespace show`.
    - name -- The name of the private endpoint connection associated with the EventHubs Namespace.
    - namespace_name -- The eventhubs namesapce name.
    - resource_group -- The resource group name of specified eventhubs namespace.
    '''
    return _call_az("az eventhubs namespace private-endpoint-connection show", locals())


def list(namespace_name, resource_group):
    '''
    

    Required Parameters:
    - namespace_name -- Name of the Namespace
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az eventhubs namespace private-endpoint-connection list", locals())


def approve(description=None, id=None, name=None, namespace_name=None, resource_group=None):
    '''
    Approve a private endpoint connection request for eventhubs namesapce.

    Optional Parameters:
    - description -- Comments for approve operation.
    - id -- The ID of the private endpoint connection associated with the EventHubs Namespace. You can get it using `az eventhubs namespace show`.
    - name -- The name of the private endpoint connection associated with the EventHubs Namespace.
    - namespace_name -- The eventhubs namesapce name.
    - resource_group -- The resource group name of specified eventhubs namespace.
    '''
    return _call_az("az eventhubs namespace private-endpoint-connection approve", locals())


def reject(description=None, id=None, name=None, namespace_name=None, resource_group=None):
    '''
    Reject a private endpoint connection request for eventhubs namespace.

    Optional Parameters:
    - description -- Comments for reject operation.
    - id -- The ID of the private endpoint connection associated with the EventHubs Namespace. You can get it using `az eventhubs namespace show`.
    - name -- The name of the private endpoint connection associated with the EventHubs Namespace.
    - namespace_name -- The eventhubs namesapce name.
    - resource_group -- The resource group name of specified eventhubs namespace.
    '''
    return _call_az("az eventhubs namespace private-endpoint-connection reject", locals())




from ... pyaz_utils import _call_az

def list():
    '''
    List supported regulatory compliance standards details and state results.
    '''
    return _call_az("az security regulatory-compliance-standards list", locals())


def show(name):
    '''
    Shows a regulatory compliance details state for selected standard.

    Required Parameters:
    - name -- name of the resource to be fetched
    '''
    return _call_az("az security regulatory-compliance-standards show", locals())




'''
Manage deployment operations at resource group.
'''
from .... pyaz_utils import _call_az

def list(name, resource_group):
    '''
    List deployment operations at resource group.

    Required Parameters:
    - name -- The deployment name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az deployment operation group list", locals())


def show(name, operation_ids, resource_group):
    '''
    Show a deployment operation at resource group.

    Required Parameters:
    - name -- The deployment name.
    - operation_ids -- A list of operation ids to show
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az deployment operation group show", locals())




'''
billing invoice section
'''
from .... pyaz_utils import _call_az

def list(account_name, profile_name):
    '''
    List the invoice sections that a user has access to. The operation is supported only for billing accounts with agreement type Microsoft Customer Agreement.

    Required Parameters:
    - account_name -- The ID that uniquely identifies a billing account.
    - profile_name -- The ID that uniquely identifies a billing profile.
    '''
    return _call_az("az billing invoice section list", locals())


def show(account_name, name, profile_name):
    '''
    Get an invoice section by its ID. The operation is supported only for billing accounts with agreement type Microsoft Customer Agreement.

    Required Parameters:
    - account_name -- The ID that uniquely identifies a billing account.
    - name -- The ID that uniquely identifies an invoice section.
    - profile_name -- The ID that uniquely identifies a billing profile.
    '''
    return _call_az("az billing invoice section show", locals())


def create(account_name, name, profile_name, display_name=None, labels=None, no_wait=None):
    '''
    Creates or updates an invoice section. The operation is supported only for billing accounts with agreement type Microsoft Customer Agreement.

    Required Parameters:
    - account_name -- The ID that uniquely identifies a billing account.
    - name -- The ID that uniquely identifies an invoice section.
    - profile_name -- The ID that uniquely identifies a billing profile.

    Optional Parameters:
    - display_name -- The name of the invoice section.
    - labels -- Dictionary of metadata associated with the invoice section. Expect value: KEY1=VALUE1 KEY2=VALUE2 ...
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az billing invoice section create", locals())


def update(account_name, name, profile_name, display_name=None, labels=None, no_wait=None):
    '''
    Creates or updates an invoice section. The operation is supported only for billing accounts with agreement type Microsoft Customer Agreement.

    Required Parameters:
    - account_name -- The ID that uniquely identifies a billing account.
    - name -- The ID that uniquely identifies an invoice section.
    - profile_name -- The ID that uniquely identifies a billing profile.

    Optional Parameters:
    - display_name -- The name of the invoice section.
    - labels -- Dictionary of metadata associated with the invoice section. Expect value: KEY1=VALUE1 KEY2=VALUE2 ...
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az billing invoice section update", locals())


def wait(account_name, name, profile_name, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the billing invoice section is met.

    Required Parameters:
    - account_name -- The ID that uniquely identifies a billing account.
    - name -- The ID that uniquely identifies an invoice section.
    - profile_name -- The ID that uniquely identifies a billing profile.

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - interval -- polling interval in seconds
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az billing invoice section wait", locals())




from ... pyaz_utils import _call_az

def list(resource_group, service_name):
    '''
    

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - service_name -- The name of the search service.
    '''
    return _call_az("az search private-link-resource list", locals())




from ..... pyaz_utils import _call_az

def create(category, display_name, name, resource_group, saved_query, workspace_name, func_alias=None, func_param=None, tags=None):
    '''
    Create a saved search for a given workspace.

    Required Parameters:
    - category -- The category of the saved search. This helps the user to find a saved search faster.
    - display_name -- Display name of the saved search.
    - name -- Name of the saved search and it's unique in a given workspace.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - saved_query -- The query expression for the saved search.
    - workspace_name -- Name of the Log Analytics Workspace.

    Optional Parameters:
    - func_alias -- Function Aliases are short names given to Saved Searches so they can be easily referenced in query. They are required for Computer Groups.
    - func_param -- The optional function parameters if query serves as a function. Value should be in the following format: 'param-name1:type1 = default_value1, param-name2:type2 = default_value2'. For more examples and proper syntax please refer to https://docs.microsoft.com/azure/kusto/query/functions/user-defined-functions.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az monitor log-analytics workspace saved-search create", locals())


def update(name, resource_group, workspace_name, add=None, category=None, display_name=None, force_string=None, func_alias=None, func_param=None, remove=None, saved_query=None, set=None, tags=None):
    '''
    Update a saved search for a given workspace.

    Required Parameters:
    - name -- Name of the saved search and it's unique in a given workspace.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- Name of the Log Analytics Workspace.

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - category -- The category of the saved search. This helps the user to find a saved search faster.
    - display_name -- Display name of the saved search.
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - func_alias -- Function Aliases are short names given to Saved Searches so they can be easily referenced in query. They are required for Computer Groups.
    - func_param -- The optional function parameters if query serves as a function. Value should be in the following format: 'param-name1:type1 = default_value1, param-name2:type2 = default_value2'. For more examples and proper syntax please refer to https://docs.microsoft.com/azure/kusto/query/functions/user-defined-functions.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - saved_query -- The query expression for the saved search.
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az monitor log-analytics workspace saved-search update", locals())


def delete(name, resource_group, workspace_name, yes=None):
    '''
    Delete a saved search for a given workspace.

    Required Parameters:
    - name -- Name of the saved search and it's unique in a given workspace.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- Name of the Log Analytics Workspace.

    Optional Parameters:
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az monitor log-analytics workspace saved-search delete", locals())


def show(name, resource_group, workspace_name):
    '''
    Show a saved search for a given workspace.

    Required Parameters:
    - name -- Name of the saved search and it's unique in a given workspace.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- Name of the Log Analytics Workspace.
    '''
    return _call_az("az monitor log-analytics workspace saved-search show", locals())


def list(resource_group, workspace_name):
    '''
    List all saved searches for a given workspace.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- Name of the Log Analytics Workspace.
    '''
    return _call_az("az monitor log-analytics workspace saved-search list", locals())




'''
Manage identities of an Azure IoT hub.
'''
from .... pyaz_utils import _call_az

def assign(name, resource_group=None, role=None, scopes=None, system_assigned=None, user_assigned=None):
    '''
    Assign managed identities to an IoT Hub

    Required Parameters:
    - name -- IoT Hub name.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - role -- Role to assign to the hub's system-assigned managed identity.
    - scopes -- Space separated list of scopes to assign the role (--role) for the system-assigned managed identity.
    - system_assigned -- Assign a system-assigned managed identity to this hub.
    - user_assigned -- Assign user-assigned managed identities to this hub. Accept space-separated list of identity resource IDs.
    '''
    return _call_az("az iot hub identity assign", locals())


def show(name, resource_group=None):
    '''
    Show the identity properties of an IoT Hub

    Required Parameters:
    - name -- IoT Hub name.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az iot hub identity show", locals())


def remove(name, resource_group=None, system_assigned=None, user_assigned=None):
    '''
    Remove managed identities from an IoT Hub

    Required Parameters:
    - name -- IoT Hub name.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - system_assigned -- Remove a system-assigned managed identity from this hub.
    - user_assigned -- Remove user-assigned managed identities from this hub. Accept space-separated list of identity resource IDs.
    '''
    return _call_az("az iot hub identity remove", locals())




from ... pyaz_utils import _call_az
from . import connection


def create(lb_frontend_ip_configs, name, resource_group, subnet, auto_approval=None, edge_zone=None, enable_proxy_protocol=None, fqdns=None, lb_name=None, location=None, private_ip_address=None, private_ip_address_version=None, private_ip_allocation_method=None, public_ip_address=None, tags=None, visibility=None, vnet_name=None):
    '''
    Create a private link service.

    Required Parameters:
    - lb_frontend_ip_configs -- Space-separated list of names or IDs of load balancer frontend IP configurations to link to. If names are used, also supply `--lb-name`.
    - name -- Name of the private link service.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - subnet -- Name or ID of subnet to use. If name provided, also supply `--vnet-name`.

    Optional Parameters:
    - auto_approval -- Space-separated list of subscription IDs to auto-approve.
    - edge_zone -- The name of edge zone.
    - enable_proxy_protocol -- Enable proxy protocol for private link service.
    - fqdns -- Space-separated list of FQDNs.
    - lb_name -- Name of the load balancer to retrieve frontend IP configs from. Ignored if a frontend IP configuration ID is supplied.
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - private_ip_address -- Static private IP address to use.
    - private_ip_address_version -- IP version of the private IP address.
    - private_ip_allocation_method -- Private IP address allocation method
    - public_ip_address -- Name or ID of the a public IP address to use.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - visibility -- Space-separated list of subscription IDs for which the private link service is visible.
    - vnet_name -- The virtual network (VNet) name.
    '''
    return _call_az("az network private-link-service create", locals())


def delete(name, resource_group):
    '''
    Delete a private link service.

    Required Parameters:
    - name -- Name of the private link service.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network private-link-service delete", locals())


def list(resource_group=None):
    '''
    List private link services.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network private-link-service list", locals())


def show(name, resource_group, expand=None):
    '''
    Get the details of a private link service.

    Required Parameters:
    - name -- Name of the private link service.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - expand -- Expands referenced resources.
    '''
    return _call_az("az network private-link-service show", locals())


def update(name, resource_group, add=None, auto_approval=None, enable_proxy_protocol=None, force_string=None, fqdns=None, lb_frontend_ip_configs=None, lb_name=None, remove=None, set=None, tags=None, visibility=None):
    '''
    Update a private link service.

    Required Parameters:
    - name -- Name of the private link service.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - auto_approval -- Space-separated list of subscription IDs to auto-approve.
    - enable_proxy_protocol -- Enable proxy protocol for private link service.
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - fqdns -- Space-separated list of FQDNs.
    - lb_frontend_ip_configs -- Space-separated list of names or IDs of load balancer frontend IP configurations to link to. If names are used, also supply `--lb-name`.
    - lb_name -- Name of the load balancer to retrieve frontend IP configs from. Ignored if a frontend IP configuration ID is supplied.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - visibility -- Space-separated list of subscription IDs for which the private link service is visible.
    '''
    return _call_az("az network private-link-service update", locals())




'''
Manage Batch certificates.
'''
from ... pyaz_utils import _call_az

def create(certificate_file, thumbprint, account_endpoint=None, account_key=None, account_name=None, password=None):
    '''
    Add a certificate to a Batch account.

    Required Parameters:
    - certificate_file -- The certificate file: cer file or pfx file.
    - thumbprint -- The certificate thumbprint.

    Optional Parameters:
    - account_endpoint -- Batch service endpoint. Alternatively, set by environment variable: AZURE_BATCH_ENDPOINT
    - account_key -- The Batch account key. Alternatively, set by environment variable: AZURE_BATCH_ACCESS_KEY
    - account_name -- The Batch account name. Alternatively, set by environment variable: AZURE_BATCH_ACCOUNT
    - password -- The password to access the certificate's private key.
    '''
    return _call_az("az batch certificate create", locals())


def delete(thumbprint, abort=None, account_endpoint=None, account_key=None, account_name=None, yes=None):
    '''
    Delete a certificate from a Batch account.

    Required Parameters:
    - thumbprint -- The certificate thumbprint.

    Optional Parameters:
    - abort -- Cancel the failed certificate deletion operation.
    - account_endpoint -- Batch service endpoint. Alternatively, set by environment variable: AZURE_BATCH_ENDPOINT
    - account_key -- The Batch account key. Alternatively, set by environment variable: AZURE_BATCH_ACCESS_KEY
    - account_name -- The Batch account name. Alternatively, set by environment variable: AZURE_BATCH_ACCOUNT
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az batch certificate delete", locals())


def show(thumbprint, account_endpoint=None, account_key=None, account_name=None, select=None):
    '''
    

    Required Parameters:
    - thumbprint -- The certificate thumbprint.

    Optional Parameters:
    - account_endpoint -- Batch service endpoint. Alternatively, set by environment variable: AZURE_BATCH_ENDPOINT
    - account_key -- Batch account key. Alternatively, set by environment variable: AZURE_BATCH_ACCESS_KEY
    - account_name -- Batch account name. Alternatively, set by environment variable: AZURE_BATCH_ACCOUNT
    - select -- An OData $select clause.
    '''
    return _call_az("az batch certificate show", locals())


def list(account_endpoint=None, account_key=None, account_name=None, filter=None, select=None):
    '''
    

    Optional Parameters:
    - account_endpoint -- Batch service endpoint. Alternatively, set by environment variable: AZURE_BATCH_ENDPOINT
    - account_key -- Batch account key. Alternatively, set by environment variable: AZURE_BATCH_ACCESS_KEY
    - account_name -- Batch account name. Alternatively, set by environment variable: AZURE_BATCH_ACCOUNT
    - filter -- An OData $filter clause. For more information on constructing this filter, see https://docs.microsoft.com/en-us/rest/api/batchservice/odata-filters-in-batch#list-certificates.
    - select -- An OData $select clause.
    '''
    return _call_az("az batch certificate list", locals())




'''
Identity details of a Recovery Services Vault.
'''
from .... pyaz_utils import _call_az

def assign(name, resource_group, system_assigned=None, user_assigned=None):
    '''
    Assign Identities to Recovery Services vault.

    Required Parameters:
    - name -- Name of the Recovery services vault.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - system_assigned -- Provide this flag to enable system assigned identity for Recovery Services Vault.
    - user_assigned -- Space-separated list of userassigned identities to be assigned to Recovery Services Vault.
    '''
    return _call_az("az backup vault identity assign", locals())


def remove(name, resource_group, system_assigned=None, user_assigned=None):
    '''
    Remove Identities of Recovery Services vault.

    Required Parameters:
    - name -- Name of the Recovery services vault.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - system_assigned -- Provide this flag to remove system assigned identity for Recovery Services Vault.
    - user_assigned -- Space-separated list of userassigned identities to be removed from Recovery Services Vault.
    '''
    return _call_az("az backup vault identity remove", locals())


def show(name, resource_group):
    '''
    Show Identities of Recovery Services vault.

    Required Parameters:
    - name -- Name of the Recovery services vault.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az backup vault identity show", locals())

